
/*
This do file creates the GDP Database that we will use in the 4 datasets (CPIS, FDI, banks, and int. reserves)
Main Source: World Bank (WDI, GDP current US$)
In the event the WB does not report the GDP for a given country in a given year, we complement this information with IMF data (WEO, GDP current prices, U.S. dollars)
In some cases, the IMF reports a prediction (not the actual GDP value). It is clarified in the database.
Cleaned data are in current US$ millions
*/
************************************************************************************************************************************

global input_GDP "${GDP}\"
global output_GDP "${GDP}\"

****************************************************
*IMPORTING IMF DATA (data in billions of current USD)
*****************************************************
*Before importing data, only leave ISO, country, and year columns in the excel file.
import excel "$input_GDP\GDP_IMF.xlsx", sheet("WEO_Data") firstrow clear
local x=1980
*Update varlist below before running code
foreach y of varlist C-AO {
rename `y' y_`x'
replace y_`x' = "" if y_`x'=="n/a"
destring y_`x', replace
local x=`x'+1
}

gen id=_n
reshape long y_, i(id) j(year)
rename y_ gdp_IMF
replace gdp_IMF = gdp_IMF *1000
label variable gdp_IMF "Data in Million of Current USD"
label variable EstimatesStartAfter "From this year onwards the IMF reports predictive values"
rename Country Country_IMF
drop id
save "$output_GDP\GDP_IMF.dta", replace

***************************************
*IMPORTING WB DATA (data in current USD)
***************************************
*Before importing data, delete blank rows at beginning of excel file. First row shoud be the years

import excel "$input_GDP\GDP_WB.xls", sheet("Data") firstrow clear
local x=1960
*Update varlist below before running code
foreach y of varlist E-BK {
rename `y' y_`x'
local x=`x'+1
}
gen id=_n
reshape long y_, i(id) j(year)
rename y_ gdp_WB
replace gdp_WB = gdp_WB /1000000
label variable gdp_WB "Data in Million of Current USD"
rename CountryCode ISO
rename CountryName Country_WB
drop id IndicatorName IndicatorCode

*Erasing data for Regions, Unions, and Group of Countries by Degree of Development
/*
	Arab World ARB
	Early-demographic dividend EAR
	East Asia & Pacific (developing only)	EAP
	East Asia & Pacific (all income levels)	EAS
	East Asia & Pacific (IDA & IBRD countries) TEA
	Europe & Central Asia (developing only)	ECA
	Europe & Central Asia (all income levels)	ECS
	East Asia & Pacific (IDA & IBRD countries) TEC
	European Union	EUU
	Fragile and conflict affected situations	FCS
	Heavily indebted poor countries (HIPC)	HPC
	Not classified	INX
	Latin America & Caribbean (developing only)	LAC
	Latin America & Caribbean (all income levels)	LCN
	Least developed countries: UN classification	LDC
	Low income	LIC
	Lower middle income	LMC
	Low & middle income	LMY
	Middle East & North Africa (all income levels)	MEA
	Middle East & North Africa (developing only)	MNA
	High income: nonOECD	NOC
	High income: OECD	OEC
	IBRD only IBD
	IDA & IBRD total IBT
	IDA blend IDB
	IDA only IDX
	IDA total IDA
	Late-demographic dividend LTE
	Latin America & the Caribbean (IDA & IBRD countries) TLA
	Middle East & North Africa (IDA & IBRD countries) TMN
	OECD members	OED
	Other small states	OSS
	Post-demographic dividend PST
	Pre-demographic dividend PRE
	Sub-Saharan Africa (all income levels)	SSF
	Small states	SST
	Upper middle income	UMC
	World	WLD
	Caribbean small states	CSS
	Middle income	MIC	
	High income	HIC
	South Asia	SAS
	South Asia (IDA & IBRD) TSA
	Sub-Saharan Africa (IDA & IBRD countries) TSS
	Sub-Saharan Africa (excluding high income) SSA
	Central Europe and the Baltics	CEB
	Euro area	EMU
	North America	NAC
	Pacific island small states	PSS
	*/
	
drop if ISO =="ARB" | ISO =="EAR" | ISO =="EAP" | ISO =="EAS" | ISO =="TEA" | ISO =="ECA" | ISO =="ECS" | ISO =="TEC" | ISO =="EUU" | ISO =="FCS" | ISO =="HPC" | ISO =="INX" | ISO =="LAC" | ISO =="LCN" | ISO =="LDC" | ISO =="LIC" | ISO =="LMC" | ///
        ISO =="LMY" | ISO =="MEA" | ISO =="MNA" | ISO =="NOC" | ISO =="OEC" | ISO =="IBD" | ISO =="IBT" | ISO =="IDB" | ISO =="IDX" | ISO =="IDA" | ISO =="LTE" | ISO =="TLA" | ISO =="TMN" | |ISO =="OED" | ISO =="OSS" | ISO =="PST" | ISO =="PRE" | ISO =="SSF" | ISO =="SST" | ISO =="UMC" | ISO =="WLD" | ISO =="CSS" | ISO =="MIC" | ISO =="HIC" | ISO =="SAS" | ISO == "TSA" | ISO =="TSS" | ISO =="SSA" | ISO =="CEB" | ISO =="EMU" | ISO =="NAC" | ISO =="PSS"

save "$output_GDP\GDP_WB.dta", replace

***************************************
*Merging the WB and IMF Datasets
***************************************
use "$output_GDP\GDP_WB.dta", clear
merge 1:1 ISO year using "$output_GDP\GDP_IMF.dta"
drop _merge
gen gdp = gdp_WB
replace gdp = gdp_IMF if gdp ==.
label variable gdp "Data in Million of Current USD. WB's Gdp. If WB is missing, IMF's Gdp"
order ISO Country_WB Country_IMF year gdp gdp_WB gdp_IMF EstimatesStartAfter
save "$output_GDP\gdp.dta", replace

erase "$output_GDP\GDP_WB.dta"
erase "$output_GDP\GDP_IMF.dta"

*Veryfing with GDP used by Matias.
*keep ISO year gdp
*rename gdp gdp_Ruth
*merge 1:1 ISO year using "Z:\OneDrive - WBG\FLASHDRIVE\CPIS 2014\gdp.dta"
*gen x=gdp_Ruth-gdp if _merge==3
