/*************************************************************************************
IMF - 1.Clean FDI

In this dofile we import the raw IMF data and clean it. We merge it with GDP and gravity control data

IMF's FDI data has "Outward" (direct investment abroad by the reporting economy) and "Inward" (direct investment in the reporting economy) direct investments. Each one of these categories are the sum of outward/inward net equity and net debt positions. We want to keep only the total values of outward and inward investment

Source: IMF CDIS. Bulk download. Format: Panel. Selected variables: Inward Direct Investment Positions and Outward Direct Investment Positions. All countries. All Counterparty Countries

*************************************************************************************/


import delimited "${FDI_IMF}\CDIS_raw.csv", clear encoding("utf-8")

global output_FDI_IMF "${FDI_IMF}\"
// global pairs "C:\Users\paolo\Dropbox\Big Sur\Stata\1.Databases\1.Country-Pairs"
// global gdp "C:\Users\paolo\Dropbox\Big Sur\Stata\1.Databases\2.GDP\DTA"
// global gc "C:\Users\paolo\Dropbox\Big Sur\Stata\1.Databases\3.Gravity Controls"

tab timeperiod, m
// drop if timeperiod<2001
keep if inrange(timeperiod,2001,2018)
*save "$output_FDI_IMF\IMF_noclean.dta", replace

*We rename several variables to have them in the standard format we use
*Check variable names when updating data. Sometimes the raw IMF data has different variable names
rename countryname Acquiror
// rename ïcountryname Acquiror
rename counterpartcountryname Target
rename countrycode acq_code
rename counterpartcountrycode tgt_code
rename timeperiod year
rename outwarddirectinvestmentpositions assets
label variable assets "Total Assets in Current USD"
rename inwarddirectinvestmentpositionsu liabilities
label variable liabilities "Total Liabilities in Current USD"
drop status v9 v10

order assets, b(liabilities)

sort Acquiror Target year

*Now we have to transform the country codes downloaded from the IMF to the ISO codes (3 digits).
kountry acq_code, from(imfn) to(iso3c)
rename _ISO3C_ acq
kountry tgt_code, from(imfn) to(iso3c)
rename _ISO3C_ tgt

*Fix countries without acq or tgt. Have to check each time data is updated as countries with problems can change
*Acquiror
replace acq ="CUW" if Acquiror =="Curacao & St. Maarten"
replace acq = "CUW" if Acquiror == "CuraÃ§ao and Sint Maarten"
replace acq = "CUW" if Acquiror == "CuraÃ§ao, Kingdom of the Netherlands"
replace acq = "CUW" if Acquiror == "Curaçao, Kingdom of the Netherlands"
replace acq ="GGY" if Acquiror =="Guernsey"
replace acq ="IMN" if Acquiror =="Isle of Man"
replace acq ="JEY" if Acquiror =="Jersey"
replace acq ="SRB" if Acquiror =="Serbia, Rep. of"
replace acq="PSE" if Acquiror=="West Bank and Gaza"
replace acq ="XKX" if Acquiror =="Kosovo, Republic of"
replace acq ="XKX" if Acquiror =="Kosovo, Rep. of"
replace acq="SXM" if Acquiror=="Sint Maarten, Kingdom of the Netherlands"


*Target
replace tgt ="AND" if Target =="Andorra"
replace tgt ="AND" if Target =="Andorra, Principality of"
replace tgt ="BES" if Target =="Bonaire, St. Eustatius and Saba"
replace tgt ="CXR" if Target =="Christmas Island"
replace tgt ="CCK" if Target =="Cocos (Keeling) Islands"
replace tgt ="CUW" if Target =="CuraÃ§ao, Kingdom of the Netherlands"
replace tgt ="ATF" if Target =="French Southern Territories"
replace tgt ="PRK" if Target =="Korea, Democratic People's Rep. of"
replace tgt ="PRK" if Target =="Korea, Dem. People's Rep. of"
replace tgt ="LIE" if Target =="Liechtenstein"
replace tgt ="MYT" if Target =="Mayotte"
replace tgt ="MCO" if Target =="Monaco"
replace tgt ="NIU" if Target =="Niue"
replace tgt ="NFK" if Target =="Norfolk Island"
replace tgt ="PCN" if Target =="Pitcairn Islands"
replace tgt ="PRI" if Target =="Puerto Rico"
replace tgt ="SRB" if Target =="Serbia, Republic of"
replace tgt ="SRB" if Target =="Serbia, Rep. of"
replace tgt ="SSD" if Target =="South Sudan"
replace tgt ="SSD" if Target =="South Sudan, Rep. of"
replace tgt ="TKL" if Target =="Tokelau Islands"
replace tgt ="TKL" if Target =="Tokelau"
replace tgt ="TCA" if Target =="Turks and Caicos Islands"
replace tgt ="TUV" if Target =="Tuvalu"
replace tgt ="VIR" if Target =="US Virgin Islands"
replace tgt ="VIR" if Target =="United States Virgin Islands"
replace tgt ="VGB" if Target =="Virgin Islands, British"
replace tgt ="VGB" if Target =="British Virgin Islands"
replace tgt ="WLF" if Target =="Wallis and Futuna"
replace tgt ="WLF" if Target =="Wallis and Futuna Islands"
replace tgt ="ESH" if Target =="Western Sahara"
replace tgt ="GGY" if Target =="Guernsey"
replace tgt ="IMN" if Target =="Isle of Man"
replace tgt ="JEY" if Target =="Jersey"
replace tgt ="XKX" if Target =="Kosovo, Republic of"
replace tgt ="XKX" if Target =="Kosovo, Rep. of"
replace tgt="CUW" if Target =="Curacao"
replace tgt="SXM" if Target=="Sint Maarten"
replace tgt="SXM" if Target=="Sint Maarten, Kingdom of the Netherlands"
replace tgt="PSE" if Target=="West Bank and Gaza"
replace tgt="CUW" if Target =="Curaçao, Kingdom of the Netherlands"
	
drop if acq =="" 
drop if tgt =="" //acq and tgt are missing for regions (e.g. Africa, US Pacific Islands, etc.) and very small countries that we don't include in our sample (e.g. the Vatican)


*Create country pair codes
gen country_dyad = acq+"_"+tgt
order acq tgt country_dyad year assets liabilities Acquiror Target
sort acq tgt year
drop if acq == tgt
*We are just interested in capital flows across borders.

*Rectangularizing the DataSet
merge 1:1 country_dyad year using "${Country_Pairs}\CountryPairs_2018.dta"   //We are merging with a perfect balanced matrix where we have all the possible counry pairs with all the years.
*The matrix has been expanded to include the year 2018.
drop Acquiror Target _merge acq_code tgt_code
keep if year >=2001
sort acq tgt year

*Data are denominated in current USD, while the GDP is in millions of current USD. If we adjust the CPIS variables, then everything will be expressed in millions.
replace assets=assets/1000000
replace liabilities=liabilities/1000000

label variable assets "Total Assets in Million Current USD"
label variable liabilities "Total Liabilities in Million Current USD"

*save "$output_FDI_IMF\IMF_Assets&Liabilities.dta", replace

*Merging with GDPs
*ACQ
gen ISO = acq
sort ISO year
merge m:1 ISO year using "$GDP\gdp.dta" 
drop if _merge ==2 //Keeping all the values from the Master File
drop _merge gdp_WB gdp_IMF EstimatesStartAfter ISO Country_IMF Country_WB
rename gdp gdp_acq

*TGT
gen ISO = tgt
sort ISO year
merge m:1 ISO year using "$GDP\gdp.dta"
drop if _merge ==2 //Keeping all the values from the Master File
drop _merge gdp_WB gdp_IMF EstimatesStartAfter ISO Country_IMF Country_WB
rename gdp gdp_tgt

*Merging with Gravity Controls
// merge m:1 acq tgt using  "$GC\GC.dta"
// drop if _merge ==2 //Keeping all the values from the Master File
// drop _merge
//
// label variable time "Time Difference" 
// label variable comlegal "Common Legal Origin"
// label variable cu  "Currency Union"
// label variable colony "Colony Relantionship"
// label variable comlang "Common Language"
// label variable dist  "Distance"
// label variable border "Common Border"
// label variable d_lat "Difference in Latitude"
// label variable d_long "Difference in Longitude"

sort acq tgt year

*save "$output_FDI_IMF\IMF_Assets&Liabilities.dta", replace

***********************************************************************************************************************************************************************
*Define VALUE variable
***********************************************************************************************************************************************************************
*At this point, for each country-pair we have two values assets (X reports assets on Y) and liabilities (Y reports liabilities on X)
*Due to reporting discrepancies, assets and liabilities may not coincide
*We tried different criteria to define the VALUE variable
*In the end, we decided to go with using assets (liabilities) if liabilities (assets) is missing, and the maximum between the two when we have both values
*I left the other criteria we tried, but "silent" so they are not run

*Criteria we use: Maximum between assets and liabilities
********************************************************
*If assets is non-missing and liabilites is missing, VALUE is equal to assets
*If assets is missing and liabilites is non-missing, VALUE is equal to liabilities
*If assets is non-missing and liabilites is non-missing, VALUE is equal to the maximum of assets and liabilities

*use "$output_FDI_IMF\IMF_Assets&Liabilities.dta", clear
gen value=.
order value, a(year)
replace value=assets if assets!=. & liabilities==.
replace value=liabilities if assets==. & liabilities!=.
replace value=max(assets, liabilities) if assets!=. & liabilities!=.

*If the assets are not reported (missing) and liabilities are reported but equal to zero then the new variable will be zero.
order value, a(year)

save "$output_FDI_IMF\FDI_IMF_clean.dta", replace

*erase "$output_FDI_IMF\IMF_Assets&Liabilities.dta"


/*

ALTERNATIVE CRITERIA WE TRIED BUT OPTED NOT TO USE

*Alt Criteria 1: Only assets are considered
***************************************
*VALUE is equal to assets. If assets is missing, VALUE is also missing

use "$output\IMF_Assets&Liabilities.dta", clear
clonevar value=assets
order value, a(year)

save "$output\FDI_IMF_cleaned_alt1.dta", replace

*Criteria 2: Assets are considered but liabilities are used to fill-in missing values
*************************************************************************************
*VALUE is equal to assets. If assets is missing, we use liabilities to fill in missing assets for that country-pair and year only.
*If both assets and liabilites are non-missing, we keep the value of assets, even if it is lower

use "$output\IMF_Assets&Liabilities.dta", clear
clonevar value=assets
replace value=liabilities if assets==. & liabilities!=.
*If the assets are not reported (missing) and liabilities are reported but equal to zero then the new variable will be zero.
order value, a(year)

save "$output\FDI_IMF_cleaned_alt2.dta", replace

*Criteria 3: Assets are considered but liabilities' growth rate is used to extrapolate missing values
****************************************************************************************************
*VALUE is equal to assets. 
*We use the following criteria to fill-in when assets are missing but we do have liabilities for that countrypair and year:
*1)We calculate the growth rate of liabilities for that year vis-a-vis the next year (liabilities(t+1)/liabilities(t)).
*2)We assume that assets had the same growth rate as liabilities. By doing this, we can extrapolate the vaue of assets in t using the growth rate of liabilities between t and t+1 and the value of assets in t+1, if avialable.

use "$output\IMF_2016_cleaned_GC.dta", clear
clonevar value=assets
order value, a(year)

*We need to be careful with the signs of the variables because otherwise the percentage changes would not be computed in the direction we need.
*For example, if liabilities increase in t and t+1 are both positive and increase over time and, also, assets are positive, we want assets to increase in absolute value
*In contrast, if assets are negative, we want assets to decrease in absolute value (become less negative)

*Identify obs in a country-pair that can be extrapolated using the growth rate of liabilities
*These are obs which have value missing but we knoe the growth rate of liabilities between t and t+1 and have the value for assets in t+1
bysort acq tgt: gen extra=1 if assets==. & assets[_n+1]!=. & assets[_n+1]!=0 & liabilities!=. & liabilities!=0 & liabilities[_n+1]!=. & liabilities[_n+1]!=0 
//I add the condition that values have to be different from zero because otherwise we cannot make any extrapolation

*Once we extrapolate one obs, we can use this value to extrapolate the value for the previous year and so on
*We can do this for missing obs for which we can calculate the growth rate of liabilities between t and t+1 and we can extrapolate the value for t+1
forvalues i=1/13 {
bysort acq tgt: replace extra=1 if (value==. & extra[_n+1]!=. & (liabilities!=. & liabilities!=0 & liabilities[_n+1]!=. & liabilities[_n+1]!=0)) //I add the condition that value has to be missing to avoid counting cases where a year in between missing was actually reported
}
//I run it 12 times, which is the total years in the sample (it is more re-runs than I need but I can be sure no value is left unreplaced)

*Identify cases in which the values of assets and liabilities is always positive so we don't have the problem of the signs
bysort acq tgt: gen extra_pos=1 if assets==. & assets[_n+1]!=. & assets[_n+1]>0  & liabilities!=. & liabilities>0 & liabilities[_n+1]!=. & liabilities[_n+1]>0

*Again, we need to consider values that we can extrapolate once we extrapolated the previous values
*In this case, if extra_pos is 1, the extrapolated value in t+1 will be positive. But we still need the condition that liabilities are both positive
forvalues i=1/13 {
bysort acq tgt: replace extra_pos=1 if (value==. & extra_pos[_n+1]==1 & (liabilities!=. & liabilities>0 & liabilities[_n+1]!=. & liabilities[_n+1]>0)) //I add the condition that value has to be missing to avoid counting cases where a year in between missing was actually reported
}

replace extra=0 if extra==.
replace extra_pos=0 if extra_pos==.

*tab extra extra_pos
*Of 1,2944 possible extrapolated values, 1,670 correspond to cases in which assets(t+1), liabilities(t), and liabilities(t+1) are positive so we don't have to care about the sign problem
*As a first version, we extrapolate only those cases and leave the others as missing. Later on we need to decide a criteria for the other cases

*Calculate growth rate of liabilities
bysort acq tgt: gen liab_rate=liabilities[_n+1]/liabilities

*Extrapolate values using the growth rate of liabilities
bysort acq tgt: replace value=value[_n+1]/liab_rate if extra_pos==1

forvalues i=1/13 {
bysort acq tgt: replace value=value[_n+1]/liab_rate if extra_pos==1
}
//I run it 12 times, which is the total years in the sample (it is more re-runs than I need but I can be sure no value is left unreplaced)

drop extra extra_pos liab_rate

save "$output\FDI_IMF_cleaned_alt3.dta", replace
