/*********************************************************************************
UNCTAD - 1. Create Database Outstock

The raw UNCTAD data is organized for each country separately. Also, for each country there is a separate file as source to any other country (outstock) and as destination
from any other country (instock). Before running this dofile, the downloaded data has to be cleaned. Thie dofiles to do this are in the "Raw" folder.

Source: Data is obtained from https://unctad.org/topic/investment/investment-statistics-and-trends

This do file imports the individual Excel files for the outstock of FDI for each country (sender data), cleans it, and merges it

Target countries are identifyied by name not by code. We adjust this using a table of
ISO 3 codes by country downloaded from UNCTAD (https://unctadstat.unctad.org/EN/Classifications.html). This table is in the dta 
"UNCTAD_countries_iso3c"

We manually adjust some countries that have errors.

*********************************************************************************/

global outstock_FDI_UN "${FDI_UN}\Outstock"
global ISOlist_FDI_UN "${FDI_UN}\"
// global gdp "C:\Users\paolo\Dropbox\Big Sur\Stata\1.Databases\2.GDP\DTA"
// global gc "C:\Users\paolo\Dropbox\Big Sur\Stata\1.Databases\3.Gravity Controls"

*We import the excel files for each country.
	*Outward FDI
	clear all
	local countries "Afghanistan Albania Algeria American_Samoa Angola Anguilla Antigua_and_Barbuda Argentina Armenia Aruba Australia Austria Azerbaijan"
	local countries "`countries' Bahamas Bahrain Bangladesh Barbados Belarus Belgium Belize Benin Bermuda Bhutan Bolivia Bosnia_and_Herzegovina Botswana Brazil British_Virgin_Islands"
	local countries "`countries' Brunei_Darussalam Bulgaria Burkina_Faso Burundi Cambodia Cameroon Canada Cape_Verde Cayman_Islands Central_African_Republic Chad Chile"
	local countries "`countries' China Hong_Kong Macao Colombia Comoros Congo Cook_Islands Costa_Rica Cote_Ivoire Croatia Cyprus Czech_Republic Democratic_People_Republic_Korea"
	local countries "`countries' Democratic_Republic_Congo Denmark Djibouti Dominica Dominican_Republic Ecuador Egypt Salvador Equatorial_Guinea Eritrea Estonia"
	local countries "`countries' Ethiopia Fiji Finland France French_Polynesia Gabon Gambia Georgia Germany Ghana Greece Guatemala Guinea Guinea_Bissau Haiti"
	local countries "`countries' Honduras Iceland Hungary India Indonesia Iran Iraq Ireland Israel Italy Jamaica Japan Jordan Kazakhstan Kenya Kuwait Kyrgyzstan"
	local countries "`countries' Lao Latvia Lebanon Lesotho Liberia Libya Lithuania Luxembourg Macedonia Madagascar Malawi Malaysia Maldives Mali Marshall_Islands Mauritania"
	local countries "`countries' Mauritius Mexico Micronesia Moldova Mongolia Montenegro Morocco Mozambique Myanmar Namibia Nauru Nepal Netherlands Netherlands_Antilles New_Caledonia"
	local countries "`countries' New_Zealand Nicaragua Niger Nigeria Niue Northern_Mariana_Islands Norway Oman Pakistan Palestine Panama Papua_New_Guinea Paraguay Peru Philippines"
	local countries "`countries' Poland Portugal Puerto_Rico Qatar Republic_Korea Reunion Romania Rusia Rwanda Saint_Helena Saint_Kitts_and_Nevis Saint_Lucia Saint_Vincent_and_Grenadines"
	local countries "`countries' Samoa Sao_Tome_and_Principe Saudi_Arabia Senegal Serbia Seychelles Sierra_Leone Singapore Slovakia Slovenia Somalia South_Africa"
	local countries "`countries' Spain Sri_Lanka Sudan Suriname Swaziland Sweden Switzerland Syria Taiwan Tajikistan Thailand Timor_Leste Togo Tonga"
	local countries "`countries' Trinidad_and_Tobago Tunisia Turkey Turks_and_Caicos Uganda Ukraine United_Arab_Emirates United_Kingdom Tanzania USA US_Virgin_Islands"
	local countries "`countries' Uruguay Vanuatu Venezuela Vietnam Yemen Zambia Zimbabwe"
					 
	foreach x of local countries {
		import excel "$outstock_FDI_UN\Excel\Outstock_`x'.xlsx", sheet("outstock") firstrow 
		rename C y_2001
		rename D y_2002
		rename E y_2003
		rename F y_2004
		rename G y_2005
		rename H y_2006
		rename I y_2007
		rename J y_2008
		rename K y_2009
		rename L y_2010
		rename M y_2011
		rename N y_2012
		rename tgt tgt_Name
		order acq tgt_Name
		drop if tgt_Name==""
			local years "01 02 03 04 05 06 07 08 09 10 11 12"
			foreach y of local years {
				tostring y_20`y', replace force
				replace y_20`y'="." if y_20`y'==".."
				replace y_20`y'="0" if y_20`y'=="-"
				destring y_20`y', replace
				}
        egen id = group(tgt_Name)
		reshape long y_, i(id) j(year)
		drop id
		rename y_ value
		keep acq tgt_Name year value
		save "$outstock_FDI_UN\DTA\Outstock_`x'.dta", replace
		clear all
	}

*Now we assemble a combined dataset with all the countries.

*OUTWARD FDI

clear all

use "$outstock_FDI_UN\DTA\Outstock_Afghanistan", clear 
	local countries2 "Albania Algeria American_Samoa Angola Anguilla Antigua_and_Barbuda Argentina Armenia Aruba Australia Austria Azerbaijan"
	local countries2 "`countries2' Bahamas Bahrain Bangladesh Barbados Belarus Belgium Belize Benin Bermuda Bhutan Bolivia Bosnia_and_Herzegovina Botswana Brazil British_Virgin_Islands"
	local countries2 "`countries2' Brunei_Darussalam Bulgaria Burkina_Faso Burundi Cambodia Cameroon Canada Cape_Verde Cayman_Islands Central_African_Republic Chad Chile"
	local countries2 "`countries2' China Hong_Kong Macao Colombia Comoros Congo Cook_Islands Costa_Rica Cote_Ivoire Croatia Cyprus Czech_Republic Democratic_People_Republic_Korea"
	local countries2 "`countries2' Democratic_Republic_Congo Denmark Djibouti Dominica Dominican_Republic Ecuador Egypt Salvador Equatorial_Guinea Eritrea Estonia"
	local countries2 "`countries2' Ethiopia Fiji Finland France French_Polynesia Gabon Gambia Georgia Germany Ghana Greece Guatemala Guinea Guinea_Bissau Haiti"
	local countries2 "`countries2' Honduras Iceland Hungary India Indonesia Iran Iraq Ireland Israel Italy Jamaica Japan Jordan Kazakhstan Kenya Kuwait Kyrgyzstan"
	local countries2 "`countries2' Lao Latvia Lebanon Lesotho Liberia Libya Lithuania Luxembourg Macedonia Madagascar Malawi Malaysia Maldives Mali Marshall_Islands Mauritania"
	local countries2 "`countries2' Mauritius Mexico Micronesia Moldova Mongolia Montenegro Morocco Mozambique Myanmar Namibia Nauru Nepal Netherlands Netherlands_Antilles New_Caledonia"
	local countries2 "`countries2' New_Zealand Nicaragua Niger Nigeria Niue Northern_Mariana_Islands Norway Oman Pakistan Palestine Panama Papua_New_Guinea Paraguay Peru Philippines"
	local countries2 "`countries2' Poland Portugal Puerto_Rico Qatar Republic_Korea Reunion Romania Rusia Rwanda Saint_Helena Saint_Kitts_and_Nevis Saint_Lucia Saint_Vincent_and_Grenadines"
	local countries2 "`countries2' Samoa Sao_Tome_and_Principe Saudi_Arabia Senegal Serbia Seychelles Sierra_Leone Singapore Slovakia Slovenia Somalia South_Africa"
	local countries2 "`countries2' Spain Sri_Lanka Sudan Suriname Swaziland Sweden Switzerland Syria Taiwan Tajikistan Thailand Timor_Leste Togo Tonga"
	local countries2 "`countries2' Trinidad_and_Tobago Tunisia Turkey Turks_and_Caicos Uganda Ukraine United_Arab_Emirates United_Kingdom Tanzania USA US_Virgin_Islands"
	local countries2 "`countries2' Uruguay Vanuatu Venezuela Vietnam Yemen Zambia Zimbabwe"


foreach x of local countries2 {
append using "$outstock_FDI_UN\DTA\Outstock_`x'"
}

label variable value "Millions of current USD"
*save "$outstock_FDI_UN\UNCTAD_Outstock.dta", replace

*The main problem is that for targets we have country-names instead of country-codes.
rename tgt_Name country
merge m:1 country using "$ISOlist_FDI_UN\UNCTAD_countries_iso3c.dta"
drop if _merge==2
drop if country=="Yugoslavia (former)"
drop if country=="Serbia and Montenegro"

replace _ISO3C_="VNM" if country=="Vietnam"
replace _ISO3C_="PSE" if country=="State of Palestine"
replace _ISO3C_="NFK" if country=="Norfolk Island"
replace _ISO3C_="BHS" if country=="Bahamas"
replace _ISO3C_="BOL" if country=="Bolivia, Plurinational State of"
replace _ISO3C_="CYM" if country=="Cayman Islands"
replace _ISO3C_="COD" if country=="Congo, Democratic Rep. of"
replace _ISO3C_="CIV" if country=="Côte d' Ivoire"
replace _ISO3C_="CZE" if country=="Czech Republic"
replace _ISO3C_="DOM" if country=="Dominican Republic"
replace _ISO3C_="FRO" if country=="Faeroe Islands"
replace _ISO3C_="GGY" if country=="Guernsey"
replace _ISO3C_="HKG" if country=="Hong Kong, China"
replace _ISO3C_="IRN" if country=="Iran, Islamic Republic of"
replace _ISO3C_="IMN" if country=="Isle of Man"
replace _ISO3C_="JEY" if country=="Jersey"
replace _ISO3C_="KOR" if country=="Korea, Republic of"
replace _ISO3C_="LAO" if country=="Lao People's Dem. Rep."
replace _ISO3C_="LIE" if country=="Liechtenstein"
replace _ISO3C_="MAC" if country=="Macao, China"
replace _ISO3C_="MHL" if country=="Marshall Islands"
replace _ISO3C_="MDA" if country=="Moldova, Republic of"
replace _ISO3C_="MCO" if country=="Monaco"
replace _ISO3C_="NLD" if country=="Netherlands"
replace _ISO3C_="ANT" if country=="Netherlands Antilles"
replace _ISO3C_="ANT" if country=="Netherlands Antilles "
replace _ISO3C_="NER" if country=="Niger"
replace _ISO3C_="PHL" if country=="Philippines"
replace _ISO3C_="PRI" if country=="Puerto Rico"
replace _ISO3C_="RUS" if country=="Russian Federation"
replace _ISO3C_="SLB" if country=="Solomon Islands"
replace _ISO3C_="SDN" if country=="Sudan"
replace _ISO3C_="SYR" if country=="Syrian Arab Republic"
replace _ISO3C_="TWN" if country=="Taiwan Province of China"
replace _ISO3C_="MKD" if country=="The FYR of Macedonia"
replace _ISO3C_="TCA" if country=="Turks and Caicos Islands"
replace _ISO3C_="GBR" if country=="UK"
replace _ISO3C_="GBR" if country=="United Kingdom"
replace _ISO3C_="USA" if country=="USA"
replace _ISO3C_="USA" if country=="United States"
replace _ISO3C_="VIR" if country=="US Virgin Islands"
replace _ISO3C_="VGB" if country=="British Virgin Islands"
replace _ISO3C_="TZA" if country=="United Rep. of Tanzania"
replace _ISO3C_="TZA" if country=="United Republic of Tanzania"
replace _ISO3C_="VEN" if country=="Venezuela, Bolivarian Rep. of"
replace _ISO3C_="VEN" if country=="Venezuela, Bolivarian Rep."
replace _ISO3C_="VEN" if country=="Venezuela"

drop if _ISO3C_==""

rename country tgt_Name
rename _ISO3C_ tgt
drop _merge

*We don't want the flows within the same country (like Brazil-Brazil).
drop if acq==tgt
drop tgt_Name

order acq tgt year

*Merging with GDPs

*ACQ
gen ISO = acq
sort ISO year
merge m:1 ISO year using "$GDP\gdp.dta" 
drop if _merge ==2 //Keeping all the values from the Master File
drop _merge gdp_WB gdp_IMF EstimatesStartAfter ISO Country_IMF Country_WB
rename gdp gdp_acq
sort acq tgt year
*TGT
gen ISO = tgt
sort ISO year
merge m:1 ISO year using "$GDP\gdp.dta"
drop if _merge ==2 //Keeping all the values from the Master File
drop _merge gdp_WB gdp_IMF EstimatesStartAfter ISO Country_IMF Country_WB
rename gdp gdp_tgt

// *Merging with Gravity Controls
// merge m:1 acq tgt using  "$GC\GC.dta"
// drop if _merge ==2 //Keeping all the values from the Master File
// drop _merge
//
// label variable time "Time Difference" 
// label variable comlegal "Common Legal Origin"
// label variable cu  "Currency Union"
// label variable colony "Colony Relantionship"
// label variable comlang "Common Language"
// label variable dist  "Distance"
// label variable border "Common Border"
// label variable d_lat "Difference in Latitude"
// label variable d_long "Difference in Longitude"

rename value assets

sort acq tgt year

save "$outstock_FDI_UN\UNCTAD_Outstock.dta", replace 

