/*********************************************************************************
UNCTAD - 3. Merge Outstock and Instock

Now we have to merge Instock and Outstock databases to have everything in just one file.

*********************************************************************************/
global input_FDI_UN "${FDI_UN}\"
global output_FDI_UN "${FDI_UN}\"
// global pairs "C:\Users\paolo\Dropbox\Big Sur\Stata\1.Databases\1.Country-Pairs"
// global gdp "C:\Users\paolo\Dropbox\Big Sur\Stata\1.Databases\2.GDP\DTA"
// global gc "C:\Users\paolo\Dropbox\Big Sur\Stata\1.Databases\3.Gravity Controls"

use "$input_FDI_UN\Outstock\UNCTAD_Outstock.dta", clear
// drop gdp_acq gdp_tgt time-d_long //these variables are twice, one in each dataset
drop gdp_acq gdp_tgt //these variables are twice, one in each dataset
merge m:m acq tgt year using "$input_FDI_UN\Instock\UNCTAD_Instock.dta"
drop _merge
order year assets liabilities gdp_acq gdp_tgt, a(tgt)

*Rectangularizing the DataSet
gen country_dyad = acq+"_"+tgt
order country_dyad, a(tgt)
merge 1:1 country_dyad year using "${Country_Pairs}\CountryPairs_2018.dta"
drop if _merge==1 //Drop country pairs not in our sample. We leave it just in case but there are no obs where merge is 1
drop _merge
sort acq tgt year
keep if year>=2001 & year<=2012 //UNCTAD data ranges from 2001 to 2012. Obs with year>2012 are added when merging the country pairs

*The dataset contains GDP and GC values only for the countries originally in the sample
*But not for the countries incorporated when rectangularizing the dataset
*So we create again the GDP and GC variables
keep acq tgt country_dyad year assets liabilities

*Merging with GDPs

*ACQ
gen ISO = acq
sort ISO year
merge m:1 ISO year using "$GDP\gdp.dta" 
drop if _merge ==2 //Keeping all the values from the Master File
drop _merge gdp_WB gdp_IMF EstimatesStartAfter ISO Country_IMF Country_WB
rename gdp gdp_acq

*TGT
gen ISO = tgt
sort ISO year
merge m:1 ISO year using "$GDP\gdp.dta"
drop if _merge ==2 //Keeping all the values from the Master File
drop _merge gdp_WB gdp_IMF EstimatesStartAfter ISO Country_IMF Country_WB
rename gdp gdp_tgt

// *Merging with Gravity Controls
// merge m:1 acq tgt using  "$GC\GC.dta"
// drop if _merge ==2 //Keeping all the values from the Master File
// drop _merge
//
// label variable time "Time Difference" 
// label variable comlegal "Common Legal Origin"
// label variable cu  "Currency Union"
// label variable colony "Colony Relantionship"
// label variable comlang "Common Language"
// label variable dist  "Distance"
// label variable border "Common Border"
// label variable d_lat "Difference in Latitude"
// label variable d_long "Difference in Longitude"

sort acq tgt year
order acq tgt country_dyad year assets liabilities gdp_acq gdp_tgt

*save "$output_FDI_UN\UNCTAD_Assets&Liabilities.dta", replace

***********************************************************************************************************************************************************************
*Define VALUE variable
***********************************************************************************************************************************************************************
/*At this point, for each country-pair we have two values assets (X reports assets on Y) and liabilities (Y reports liabilities on X)
Due to reporting discrepancies, assets and liabilities may not coincide
Also, when one of the values are missing we could use the other one to fill-in
We tried different criteria to define the VALUE variable
In the end, we decided to go with using assets (liabilities) if liabilities (assets) is missing, and the maximum between the two when we have both values
I left the other criteria we tried, but "silent" so they are not run
*/

*Criteria we use: Maximum between assets and liabilities
*************************************************************************************
*If assets is non-missing and liabilites is missing, VALUE is equal to assets
*If assets is missing and liabilites is non-missing, VALUE is equal to liabilities
*If assets is non-missing and liabilites is non-missing, VALUE is equal to the maximum of assets and liabilities

*use "$output_FDI_UN\UNCTAD_Assets&Liabilities.dta", clear
gen value=.
order value, a(year)
replace value=assets if assets!=. & liabilities==.
replace value=liabilities if assets==. & liabilities!=.
replace value=max(assets, liabilities) if assets!=. & liabilities!=.
*Note that if the assets are not reported (missing) and liabilities are reported but equal to zero then the new variable will be zero.

order value, a(year)

save "$output_FDI_UN\FDI_UNCTAD_clean.dta", replace

*erase "$output_FDI_UN\UNCTAD_Assets&Liabilities.dta"

/*

ALTERNATIVE CRITERIA WE TRIED BUT OPTED NOT TO USE

*Alt Criteria 1: Only assets are considered
***************************************
*VALUE is equal to assets. If assets is missing, VALUE is also missing

use "$input_general\UNCTAD_Assets&Liabilities.dta", clear
clonevar value=assets
order value, a(year)

save "$input_general\_FDI_UNCTAD_cleaned_alt1.dta", replace

*Alt Criteria 2: Assets are considered but liabilities are used to fill-in missing values
*****************************************************************************************
*VALUE is equal to assets. If assets is missing, we use liabilities to fill in missing assets for that country-pair and year only.
*If both assets and liabilites are non-missing, we keep the value of assets, even if it is lower

use "$input_general\UNCTAD_Assets&Liabilities.dta", clear
clonevar value=assets
order value, a(year)
replace value=liabilities if assets==. & liabilities!=.
*If the assets are not reported (missing) and liabilities are reported but equal to zero then the new variable will be zero.

save "$input_general\_FDI_UNCTAD_cleaned_alt2.dta", replace

*Alt Criteria 3: Assets are considered but liabilities' growth rate is used to extrapolate missing values
****************************************************************************************************
*VALUE is equal to assets. 
*We use the following criteria to fill-in when assets are missing but we do have liabilities for that countrypair and year:
*1)We calculate the growth rate of liabilities for that year vis-a-vis the next year (liabilities(t+1)/liabilities(t)).
*2)We assume that assets had the same growth rate as liabilities. By doing this, we can extrapolate the vaue of assets in t using the growth rate of liabilities between t and t+1 and the value of assets in t+1, if avialable.

use "$input_general\UNCTAD_Assets&Liabilities.dta", clear
clonevar value=assets
order value, a(year)

*We need to be careful with the signs of the variables because otherwise the percentage changes would not be computed in the direction we need.
*For example, if liabilities increase in t and t+1 are both positive and increase over time and, also, assets are positive, we want assets to increase in absolute value
*In contrast, if assets are negative, we want assets to decrease in absolute value (become less negative)

*Identify obs in a country-pair that can be extrapolated using the growth rate of liabilities
*These are obs which have value missing but we know the growth rate of liabilities between t and t+1 and we also have the value for assets in t+1
bysort acq tgt: gen extra=1 if assets==. & assets[_n+1]!=. & assets[_n+1]!=0 & liabilities!=. & liabilities!=0 & liabilities[_n+1]!=. & liabilities[_n+1]!=0 
//I add the condition that values have to be different from zero because otherwise we cannot make any extrapolation

*Once we extrapolate one obs, we can use this value to extrapolate the value for the previous year and so on
*We can do this for missing obs for which we can calculate the growth rate of liabilities between t and t+1 and we can extrapolate the value for t+1
forvalues i=1/13 {
bysort acq tgt: replace extra=1 if (value==. & extra[_n+1]!=. & (liabilities!=. & liabilities!=0 & liabilities[_n+1]!=. & liabilities[_n+1]!=0)) //I add the condition that value has to be missing to avoid counting cases where a year in between two missing values was actually reported
}
//I run it 12 times, which is the total years in the sample (it is more re-runs than I need but I can be sure no value is left unreplaced)

*Identify cases in which the values of assets and liabilities is always positive so we don't have the problem of the signs
bysort acq tgt: gen extra_pos=1 if assets==. & assets[_n+1]!=. & assets[_n+1]>0  & liabilities!=. & liabilities>0 & liabilities[_n+1]!=. & liabilities[_n+1]>0

*Again, we need to consider values that we can extrapolate once we extrapolated the previous values
*In this case, if extra_pos is 1, the extrapolated value in t+1 will be positive. But we still need the condition that liabilities are both positive
forvalues i=1/13 {
bysort acq tgt: replace extra_pos=1 if (value==. & extra_pos[_n+1]==1 & (liabilities!=. & liabilities>0 & liabilities[_n+1]!=. & liabilities[_n+1]>0)) //I add the condition that value has to be missing to avoid counting cases where a year in between missing was actually reported
}

replace extra=0 if extra==.
replace extra_pos=0 if extra_pos==.

*tab extra extra_pos
*Of 1,253 possible extrapolated values, 1,168 correspond to cases in which assets(t+1), liabilities(t), and liabilities(t+1) are positive so we don't have to care about the sign problem
*As a first version, we extrapolate only those cases and leave the others as missing. Later on we need to decide a criteria for the other cases

*Calculate growth rate of liabilities
bysort acq tgt: gen liab_rate=liabilities[_n+1]/liabilities

*Extrapolate values using the growth rate of liabilities
bysort acq tgt: replace value=value[_n+1]/liab_rate if extra_pos==1

forvalues i=1/13 {
bysort acq tgt: replace value=value[_n+1]/liab_rate if extra_pos==1
}
//I run it 12 times, which is the total years in the sample (it is more re-runs than I need but I can be sure no value is left unreplaced)

drop extra extra_pos liab_rate

save "$input_general\_FDI_UNCTAD_cleaned_alt3.dta", replace

