/*
1. LMF - Clean

This dofile cleans the LMF data and puts it in a format similar to our data (at 2020)

*/

import excel "${LMF}\LMF data_1970-2020.xlsx", sheet("Dataset") firstrow clear

global output_LMF "${LMF}\"

tab Year, m
drop if Year<2001

*LMF data separates portfolio debt and equity, so we sum these two together
*Also, banking is under the name "other investments"

keep Country IFS_Code Year Portfolioequityassets FDIassets FXReservesminusgold Portfoliodebtassets Otherinvestmentassets

rename Country Acquiror
rename IFS_Code acq_code
rename Year year
rename Portfolioequityassets portequity_value
rename FDIassets FDI_value
rename FXReservesminusgold IR_value
rename Portfoliodebtassets portdebt_value
rename Otherinvestmentassets bank_value

*Sum portfolio debt and equity
gen port_value = portequity_value+portdebt_value
drop portequity_value portdebt_value

*Now we have to transform the country codes (which are theIMF codes) to the ISO codes (3 digits).
kountry acq_code, from(imfn) to(iso3c)
rename _ISO3C_ acq

replace acq ="AND" if Acquiror =="Andorra"
replace acq ="VGB" if Acquiror =="British Virgin Islands"
replace acq ="CUW" if Acquiror =="Curacao"
replace acq ="GGY" if Acquiror =="Guernsey"
replace acq ="IMN" if Acquiror =="Isle of Man"
replace acq ="JEY" if Acquiror =="Jersey"
replace acq ="XKX" if Acquiror =="Kosovo"
replace acq ="XKX" if Acquiror =="Kosovo"
replace acq ="SRB" if Acquiror =="Serbia"
replace acq ="SXM" if Acquiror =="Sint Maarten"
replace acq ="SSD" if Acquiror =="South Sudan"
replace acq ="TCA" if Acquiror =="Turks and Caicos"
replace acq ="TUV" if Acquiror =="Tuvalu"
replace acq ="PSE" if Acquiror =="West Bank and Gaza"

drop if acq =="" //acq is missing for regions (e.g. Euro Area)
drop acq_code
order acq, b(Acquiror)

sort acq year
drop Acquiror

*Data are already denominated in million USD. We label variables to note this
label variable bank_value "Bank Assets in Million Current USD"
label variable FDI_value "FDI Assets in Million Current USD"
label variable port_value "Portfolio Securities Assets in Million Current USD"

order bank_value port_value FDI_value, a(year)

*Classify countries into regions
gen n1_acq =0
replace n1_acq=1 if acq=="AND" |acq=="AUT" |acq=="BEL" |acq=="CAN" |acq=="DNK" |acq=="FIN" |acq=="FRA" |acq=="DEU" |acq=="GRC" |acq=="ISL" |acq=="IRL" |acq=="ITA" |acq=="JPN" |acq=="LIE" |acq=="LUX" |acq=="MCO" | ///
acq=="NLD" |acq=="NOR" |acq=="PRT" |acq=="SMR" |acq=="ESP" |acq=="SWE" |acq=="CHE" |acq=="GBR" |acq=="USA" 

gen OFC_acq = 0
replace OFC_acq =1  if acq=="AND" | acq=="AIA" | acq=="ABW" | acq=="BHS" | acq=="BLZ" | acq=="BMU" | acq=="VGB" | acq=="CYM" | acq=="COK" | acq=="CYP" | acq=="GIB" | acq=="GGY" | acq=="IMN" | acq=="JEY" | ///
acq=="LIE" | acq=="MAC" | acq=="MCO" | acq=="MSR" | acq=="ANT" | acq=="PLW" | acq=="PAN" | acq=="WSM" | acq=="SYC" | acq=="TCA" | acq=="VUT"

replace n1_acq =0 if OFC_acq ==1

g s1_acq=0
replace s1_acq=1 if n1_acq==0 & OFC_acq==0

save "$output_LMF\LMF_clean.dta", replace

*Input
save "$input_databases\_LMF.dta", replace



