********************************************************************************
* Title: Data Preparation
* Paper: Bilateral International Investments: The Big Sur?
* Last update: June 14 2023
* Authors: Paolo Sabella & Esteban Espinoza
********************************************************************************
/*
The following dofile creates the main databases which will use across the T&Fs. 
See the "readme" file to check how to distribute the folders for replication.
*/

* 0. Define Directory, globals and others.
********************************************************************************
clear all
global dir_databases "${dir}\1.Raw Databases"
global input_databases "${dir}\2.Cleaned Databases"
global dofiles  "${dir}\3.Dofiles\1.Data Cleaning"
global Country_Pairs "${dir_databases}\Country-pairs"
global GDP "${dir_databases}\1.GDP"
global CPIS "${dir_databases}\2.CPIS"
global FDI_IMF  "${dir_databases}\3.FDI\FDI_IMF"
global FDI_UN  "${dir_databases}\3.FDI\FDI_UNCTAD"
global FDI_merge "${dir_databases}\3.FDI\Merge IMF and UNCTAD"
global IR "${dir_databases}\4.IR"
global LMF "${dir_databases}\5.LMF data"
global price_deflator "${dir_databases}\6.Price deflator"

* 1. Construct GDP
********************************************************************************
do "${dofiles}\01_Construct GDP Data.do"

* 2. CPIS
********************************************************************************
do "${dofiles}\02_01_Construct CPIS Data_2018.do"
do "${dofiles}\02_02_Problem with zeros in 2004 and 2005.do"

* 3. FDI
********************************************************************************
do "${dofiles}\03_01_Clean FDI_IMF.do"
do "${dofiles}\03_02_01_Create Database_Outstock.do"
do "${dofiles}\03_02_02_Create Database_Instock.do"
do "${dofiles}\03_02_03_Merge Outstock and Instock.do"
do "${dofiles}\03_03_Merge UNCTAD and IMF.do"

* 4. IR
********************************************************************************
do "${dofiles}\04_Clean IR.do"

* 5. LMF (Lane Milesi-Ferreti)
*******************************************************************************
do "${dofiles}\05_Clean LMF data.do"

* 6. Price Deflator
********************************************************************************
do "${dofiles}\06_Clean raw data.do"

* 7. GDP by classification
********************************************************************************
do "${dofiles}\07_01_Regions GDP.do"
do "${dofiles}\07_02_Regions GDP regions.do"
do "${dofiles}\07_03_Regions GDP OFC.do"

