********************************************************************************
* Title: Tables and Figures
* Paper: Bilateral International Investments: The Big Sur?
* Last update: June 14 2023
* Author: Paolo Sabella & Esteban Espinoza
********************************************************************************
/*

The following dofile creates the tables which we use in the Paper.
- It is required to run first the do file: 00_Data_preparation.do
*/

* 0. Define Directory, globals and others.
********************************************************************************
clear all
global Input "${dir}\2.Cleaned Databases"
global Dofiles "${dir}\3.Dofiles\2.Tables and Figures"
global Output "${dir}\4.Tables and Figures"

* 1. Tables
********************************************************************************
* Table 1 and Table 2. Intensive Margin
do "${Dofiles}\T1_T2.do"

* Table 3. Growth of International Investment Positions (Growth in Intensive Margin)
do "${Dofiles}\T3.do"

* Table 4. Role of Offshore Financial Centers
do "${Dofiles}\T4.do"

* Table 5. Intensive Margin with Regional GDPs
do "${Dofiles}\T5.do"

* Table 6. Growth of International Investment Positions with Regional GDPs (Growth in Intensive Margin controlling by size)
do "${Dofiles}\T6.do"

* Table 7. Extensive Margin
do "${Dofiles}\T7.do"

* Table 8. Growth in Active Links (Growth in Extensive Margin)
do "${Dofiles}\T8.do"

* Table 9. Extensive Margin: Old and New Connections
do "${Dofiles}\T9.do"

* Appendix Table 1 and Online Appendix Table 1. List of Countries
do "${Dofiles}\AT1_OAT1.do"

* Online Appendix Table 2. Intensive Margin - Portfolio Equity vs. Debt
do "${Dofiles}\OAT2.do"

* Online Appendix Table 3. FDI: Intensive Margin Regressions Robustness.
do "${Dofiles}\OAT3.do"

* Online Appendix Table 4. FDI: Extensive Margin Regressions Robustness.
do "${Dofiles}\OAT4.do"

* 2. Figures and Combinations
********************************************************************************
* Figure 1. Evolution of International Investment Positions (Comparison with Lane and Milesi-Ferretti)
do "${Dofiles}\F1.do"

* Figure 2. The Scale of International Investment Positions (Evolution of Regional Level Investments)
do "${Dofiles}\F2.do"

* Figure 3, Figure 4, Figure 5 and Online Appendix Figure 5. Regional Analysis
do "${Dofiles}\F3_F4_F5_OAT5.do"

* Figure 6. Growth of International Investment Positions (Growth in Intensive Margin)
do "${Dofiles}\F6.do"

* Figure 7. The Proliferation of South-South Links (Databases to use in R.)
do "${Dofiles}\F7.do"

*  Online Appendix Figure 1. Number of Source and Destination Countries by Year
do "${Dofiles}\OAF1.do"

*  Online Appendix Figure 2. Number of Source and Destination Countries by Year
do "${Dofiles}\OAF2.do"

*  Online Appendix Figure 3 and 4. Figure 4 and 5 considering China and Hong Kong as Region
do "${Dofiles}\OAF3_OAF4.do"

