/* **********************************************************************************************************************************************************************************************
This do file generates the input for AT1 and OAT1  - List of Countries

This table includes a list of all countries in our dataset, indicating whether they appear as reporting as source and/or destination in each dataset

The list includes all countries, even OFCs

A country is considered to be reporting if, for any year, the sum of all bilateral positions for which the country is source/destination is non-missing
********************************************************************************************************************************************************************************************** */

clear all
set more off

* NOTE: If hoy have access to IBS data, change the "3" to "4"
forvalues i=1/3 {
	
if `i'==1 {
use "$Input\_CPIS.dta" ,clear
local database "CPIS" 
}
if `i'==2 {
use "$Input\_FDI.dta" ,clear 
local database "FDI"
}
if `i'==3 {
use "$Input\_IR.dta" ,clear 
local database "IR"
}
if `i'==4 {
use "$Input\_IBS.dta" ,clear 
local database "IBS"
}


**************
*By sender
**************
*We don't care about the year, we only care if the sender country appears in the dataset as a sender
*A sender could be reporting either positive, negative or zero values

preserve

bysort acq: egen reporter_sender=sum(value), missing

collapse (max) reporter_sender, by(acq)

keep if reporter_sender!=. //Keep reporters only

*We have the ISO codes but we are interested in knowing which country is behind each code
kountry acq, from(iso3c)
*While moving from the iso3c to any other format the command "kountry" creates a new variable called NAMES_STD
rename NAMES_STD country_name

sort country_name

*We save the list of reporting countries on a dta file so then we can merge all the lists together and have a compiled table of reporting countries by type of flow.
*We rename acq/tgt to ISO so we can merge it properly.
rename acq ISO
drop reporter_sender

save "$Output\AT1_`database'_S.dta", replace

restore

*************
*By receiver
*************
*We can obtain the reporting receivers for IBS, CPIS and FDI but not for IR, which is at the C-R level

if `i'==1 | `i'==2 | `i' ==4 {

bysort tgt: egen reporter_receiver=sum(value), missing

collapse (max) reporter_receiver, by(tgt)

keep if reporter_receiver!=. //Keep reporters only

kountry tgt, from(iso3c)
rename NAMES_STD country_name

sort country_name

rename tgt ISO
drop reporter_receiver

save "$Output\AT1_`database'_R.dta", replace

}
}

*********************
*Create Table for AT1
*********************
*We merge the list of reporting countries in each dataset into a single file
use "$Output\AT1_CPIS_S.dta", clear
gen CPIS_S = 1
merge 1:1 ISO using  "$Output\AT1_CPIS_R.dta"
*If _merge=1, the country is a CPIS sender but not a CPIS receiver, so we don't identify them as CPIS receiver
gen CPIS_R = 1 if _merge!=1
drop _merge

// local database "FDI_S FDI_R IR_S IBS_S IBS_R" // If you have access to Banking database, uncomment this.
local database "FDI_S FDI_R IR_S"


foreach x of local database {
merge 1:1 ISO using "$Output\AT1_`x'.dta"
gen `x'= 1 if _merge !=1 //_merge=1 for countries already in the list that were not matched. Those are not senders/receivers in the datasets that we are merging
drop _merge
}

// * Save data and sent to Goetz
// save "$Output\AT1_merge.dta", replace

*Fix problems with ISO codes and clean country names to World Bank format
*************************************************************************
replace country_name = "Bahamas, The" if ISO == "BHS"
replace country_name = "Bonaire, Sint Eustatius and Saba" if ISO == "BES"
replace country_name = "Brunei Darussalam" if ISO == "BRN"
replace country_name = "Cabo Verde" if ISO == "CPV"
replace country_name = "Congo, Rep." if ISO == "COG"
replace country_name = "Congo, Dem. Rep." if ISO == "COD"
replace country_name = "Curacao" if ISO == "CUW"
replace country_name = "Egypt, Arab Rep." if ISO == "EGY"
replace country_name = "French Southern Territories" if ISO == "ATF"
replace country_name = "Gambia, The" if ISO == "GMB"
replace country_name = "Guernsey" if ISO == "GGY"
replace country_name = "Hong Kong SAR, China" if ISO == "HKG"
replace country_name = "Iran, Islamic Rep." if ISO == "IRN"
replace country_name = "Isle of Man" if ISO == "IMN"
replace country_name = "Jersey" if ISO == "JEY"
replace country_name = "Korea, Dem. Rep." if ISO == "PRK"
replace country_name = "Korea, Rep." if ISO == "KOR"
replace country_name = "Kosovo, Rep." if ISO == "XKX"
replace country_name = "LAO, PDR" if ISO == "LAO"
replace country_name = "Macao SAR, China" if ISO == "MAC"
replace country_name = "Macedonia, FYR" if ISO == "MKD"
replace country_name = "Micronesia, Fed. Sts." if ISO == "FSM"
replace country_name = "Netherlands Antilles" if ISO == "ANT"
replace country_name = "Norfolk Island" if ISO == "NFK"
replace country_name = "Northern Mariana Islands" if ISO == "MNP"
replace country_name = "Pitcairn" if ISO == "PCN"
replace country_name = "Russian Federation" if ISO == "RUS"
replace country_name = "Serbia" if ISO == "SRB"
replace country_name = "Sint Maarten" if ISO == "SXM"
replace country_name = "St. Helena" if ISO == "SHN"
replace country_name = "St. Kitts and Nevis" if ISO == "KNA"
replace country_name = "St. Lucia" if ISO == "LCA"
replace country_name = "St. Pierre and Miquelon" if ISO == "SPM"
replace country_name = "St. Vincent and the Grenadines" if ISO == "VCT"
replace country_name = "Syrian Arab Republic" if ISO == "SYR"
replace country_name = "Taiwan, China" if ISO == "TWN"
replace country_name = "Timor-Leste" if ISO == "TLS"
replace country_name = "Tokelau" if ISO == "TKL"
replace country_name = "Turks and Caicos" if ISO == "TCA"
replace country_name = "Venezuela. R.B." if ISO == "VEN"
replace country_name = "Virgin Islands, United States" if ISO == "VIR"
replace country_name = "West Bank and Gaza" if ISO == "PSE"
replace country_name = "Yemen, Rep." if ISO == "YEM"

replace country_name = "China (Mainland)" if ISO == "CHN"

*North Countries (High income definition including offshore centers)
**************************************************
gen n1 =0
replace n1=1 if ISO=="AND" |ISO=="AUT" |ISO=="BEL" |ISO=="CAN" |ISO=="DNK" |ISO=="FIN" |ISO=="FRA" |ISO=="DEU" |ISO=="GRC" |ISO=="ISL" |ISO=="IRL" |ISO=="ITA" |ISO=="JPN" |ISO=="LIE" |ISO=="LUX" |ISO=="MCO" | ///
ISO=="NLD" |ISO=="NOR" |ISO=="PRT" |ISO=="SMR" |ISO=="ESP" |ISO=="SWE" |ISO=="CHE" |ISO=="GBR" |ISO=="USA" 

* Additional countries in North based on BIS classification (including OFCs) 
	replace n1=1 if inlist(ISO,"ABW","AIA","AND","ANT","AUS","BES","BMU","CUW","CYM")
	replace n1=1 if inlist(ISO,"CYP","EST","FLK","FRO","GGY","GIB","GRL","IMN","JEY")
	replace n1=1 if inlist(ISO,"LIE","LTU","LVA","MLT","MSR","NCL","NZL","PUS","PYF")
	replace n1=1 if inlist(ISO,"SHN","SVK","SVN","SXM","TCA","VAT","VGB","WIN","WLF")


	* Note that the additional North countries include reallocated OFCs. 
	* If we want to continue excluding OFCs, we can run the script below unchanged. 
	

*Offshore Centers (25)
**********************
gen OFC = 0
replace OFC =1  if ISO=="AND" | ISO=="AIA" | ISO=="ABW" | ISO=="BHS" | ISO=="BLZ" | ISO=="BMU" | ISO=="VGB" | ISO=="CYM" | ISO=="COK" | ISO=="CYP" | ISO=="GIB" | ISO=="GGY" | ISO=="IMN" | ISO=="JEY" | ///
ISO=="LIE" | ISO=="MAC" | ISO=="MCO" | ISO=="MSR" | ISO=="ANT" | ISO=="PLW" | ISO=="PAN" | ISO=="WSM" | ISO=="SYC" | ISO=="TCA" | ISO=="VUT" 

*Excluding Offshore centers from North Countries, also generate North OFCs
**********************************************
gen n_OFC = (n1 == 1 & OFC == 1)
replace n1 =0 if OFC ==1

*South countries (excluding offshore centers)
*********************************************************
g s1=0
replace s1=1 if n1==0 & OFC ==0

********************************************************************************
* Subgroups
********************************************************************************

*Africa + Sudan + Somalia
**************************************************
gen africa=0
inlist2 ISO, values(AGO, BEN, BWA, BFA, BDI, CMR, CPV, CAF, TCD, COM, COD, COG, CIV, DJI, GNQ, ERI, ETH, GAB, GMB, GHA, GIN, GNB, KEN, LSO, LBR, MDG, MWI, MLI, MRT, MUS, MOZ, NAM, NER, NGA, RWA, STP, SEN, SYC, SLE, ZAF, SSD, SUD, SWZ, TZA, TGO, UGA, ZMB, ZWE, SDN, SOM)
replace africa=1 if inlist2==1 & OFC ==0 & n1 ==0
drop inlist2

*Caribbean + Barbados + Cuba + Puerto Rico + Virgin Islands (US)
**************************************************
gen caribbean=0
inlist2 ISO, values(ATG, ABW, BLZ, DMA, GRD, GUY, JAM, KNA, LCA, VCT, TTO, BRB, CUB, PRI, VIR)
replace caribbean=1 if inlist2==1 & OFC ==0 & n1 ==0
drop inlist2

*LATAM + Suriname
**************************************************
gen latam=0
inlist2 ISO, values(ARG, BOL, BRA, CHL, COL, CRI, DOM, ECU, SLV, GTM, HTI, HND, MEX, NIC, PAN, PRY, PER, URY, VEN, SUR)
replace latam=1 if inlist2==1 & OFC ==0 & n1 ==0
drop inlist2

*Commonwealth of Independent States (CIS)
**************************************************
gen cis=0
inlist2 ISO, values(ARM, AZE, GEO, KAZ, KGZ, RUS, TJK, TKM, UZB, MNG)
replace cis=1 if inlist2==1 & OFC ==0 & n1 ==0
drop inlist2

*Emerging Asia + Afghanistan + America Samoa + Tuvalu
**************************************************
gen asia=0
inlist2 ISO, values(BGD, BTN, BRN, KHM, CHN, FJI, HKG, IND, IDN, KIR, KOR, PRK, LAO, MAC, MYS, MDV, MMR, NPL, PAK, PNG, PHL, WSM, SGP, SLB, LKA, TWN, THA, TLS, TON, VUT, VNM, AFG, ASM, TUV)
replace asia=1 if inlist2==1 & OFC ==0 & n1 ==0
drop inlist2

*Emerging Europe + Malta + North Macedonia + Montenegro + Kosovo (excl Cyprus, Estonia, Lithuania, Latvia and Slovakia)
**************************************************
gen europe=0
inlist2 ISO, values(ALB, BLR, BIH, BGR, HRV, CZE, HUN, MDA, POL, ROU, SRB, TUR, UKR, MKD, MNE, XKX )
replace europe=1 if inlist2==1
drop inlist2


* Middle East and North Africa: (MENA) + ISRAEL + Iraq + West bank and Gaza
**************************************************
gen mena=0
inlist2 ISO, values(BHR, IRN, JOR, KWT, LBN, OMN, QAT, SAU, SYR, ARE, EGY, YEM, DZA, LBY, MAR, TUN, ISR, IRQ, PSE)
replace mena=1 if inlist2==1 & OFC ==0 & n1 ==0
drop inlist2


* New groups (3) and Asia
**********************
* CIS - East europe
gen CIS_EUR=1 if cis==1 | europe==1
replace CIS_EUR=0 if CIS_EUR==.

* Africa - Middle East and North Africa
gen AFR_mena=1 if mena==1 | africa==1
replace AFR_mena=0 if AFR_mena==.

* Latin America and Caribbean Countries	
gen LAT_CAR=1 if latam==1 | caribbean==1
replace LAT_CAR=0 if LAT_CAR==.


* Not classified
********************
inlist2 ISO, values(ATF, CCK, CXR, ESH, FSM, GLP,GUF,GUM, MHL, MTQ,MYT,NFK,NIU,NRU,PCN,REU,SPM,TKL)
replace s1 = . if inlist2 == 1 
gen others = 1 if inlist2 == 1

drop inlist2

order n1 s1 africa asia CIS_EUR LAT_CAR mena OFC CPIS_S CPIS_R FDI_S FDI_R IR_S n_OFC,a(country_name)
gsort -n1 -africa -asia -CIS_EUR -LAT_CAR -mena -others -OFC country_name

save "$Output\AT1_aux.dta", replace

* Input the quintiles
********************************************************************************
use "$Input\_CPIS.dta" ,clear
preserve
gen OFC = 0
replace OFC =1  if acq=="AND" | acq=="AIA" | acq=="ABW" | acq=="BHS" | acq=="BLZ" | acq=="BMU" | acq=="VGB" | acq=="CYM" | acq=="COK" | acq=="CYP" | acq=="GIB" | acq=="GGY" | acq=="IMN" | acq=="JEY" | ///
acq=="LIE" | acq=="MAC" | acq=="MCO" | acq=="MSR" | acq=="ANT" | acq=="PLW" | acq=="PAN" | acq=="WSM" | acq=="SYC" | acq=="TCA" | acq=="VUT" 
drop if OFC == 1
drop OFC

collapse (mean) gdp_acq1 = gdp_acq , by(acq)
xtile pct_gdp_s = gdp_acq1, n(5)
gen fifth_quintile = 1 if pct_gdp_s == 5
rename acq ISO
save "$Output\aux_GDP_rank_s.dta", replace
restore

* Merge the data
use "$Output\AT1_aux.dta", clear
merge 1:1 ISO using "$Output\aux_GDP_rank_s.dta", keepus(fifth_quintile)
keep if _merge == 3 | _merge == 1
drop _merge
save "$Output\AT1_aux.dta", replace


* Reporting
********************************************************************************
local database "CPIS"
foreach x of local database{
use "$Input\_`x'.dta", clear

*Obtain the list of first and last reporting year per country and dataset
preserve
*We start by identifying for which years each country is reporting as sender
bysort acq year: egen reporter_sender=sum(value), missing
gen report_dummy=1 if reporter_sender!=.
keep acq year report_dummy
*Then, we identify first and last year a country reported
bysort acq: egen first_year_sender_`x'=min(year) if report_dummy==1
// bysort acq: egen last_year=max(year) if report_dummy==1
collapse (min) first_year_sender_`x', by(acq)
rename acq ISO
save "$Output\reporting_s_`x'.dta", replace	
restore

*Obtain the list of first and last reporting year per country and dataset
*We start by identifying for which years each country is reporting as receiver
bysort tgt year: egen reporter_receiver=sum(value), missing
gen report_dummy=1 if reporter_receiver!=.
keep tgt year report_dummy
*Then, we identify first and last year a country reported
bysort tgt: egen first_year_receiver_`x'=min(year) if report_dummy==1
// bysort acq: egen last_year=max(year) if report_dummy==1
collapse (min) first_year_receiver_`x', by(tgt)
rename tgt ISO
save "$Output\reporting_r_`x'.dta", replace	

merge 1:1 ISO using "$Output\reporting_s_`x'.dta", nogen
save "$Output\reporting_`x'.dta", replace	
erase "$Output\reporting_s_`x'.dta"
erase "$Output\reporting_r_`x'.dta"
}

* IBS FDI. Given mirror data, we can recover information of source countries from destination countries.
// local database "FDI IBS" // If you have access to Banking database, uncomment this.
local database "FDI"
foreach x of local database{
use "$Input\_`x'.dta", clear

*Obtain the list of first and last reporting year per country and dataset
preserve
*We start by identifying for which years each country is reporting as sender
bysort acq year: egen reporter_sender=sum(value), missing
gen report_dummy=1 if reporter_sender!=.
keep acq year report_dummy
*Then, we identify first and last year a country reported
bysort acq: egen first_year_sender_`x'=min(year) if report_dummy==1
// bysort acq: egen last_year=max(year) if report_dummy==1
collapse (min) first_year_sender_`x', by(acq)
rename acq ISO
save "$Output\reporting_s_`x'.dta", replace	
restore

*Obtain the list of first and last reporting year per country and dataset
*We start by identifying for which years each country is reporting as receiver. Also, we identify from which year each country is reporting liabilities.
bysort tgt year: egen reporter_receiver=sum(value), missing
gen report_dummy=1 if reporter_receiver!=.
bys tgt year: egen reporter_receiver_liabilities_UN = sum(liabilities_UNCTAD) , missing
gen report_dummy_l = 1 if reporter_receiver_liabilities_UN != .
bys tgt year: egen reporter_receiver_liabilities_IM = sum(liabilities_IMF), missing
replace report_dummy_l = 1 if reporter_receiver_liabilities_IM != .
keep tgt year report_dummy report_dummy_l 
*Then, we identify first and last year a country reported
bysort tgt: egen first_year_receiver_`x'=min(year) if report_dummy==1
bysort tgt: egen first_year_receiver_`x'_l=min(year) if report_dummy_l==1
// bysort acq: egen last_year=max(year) if report_dummy==1

collapse (min) first_year_receiver_`x'*, by(tgt)
rename tgt ISO
save "$Output\reporting_r_`x'.dta", replace	

merge 1:1 ISO using "$Output\reporting_s_`x'.dta", nogen
save "$Output\reporting_`x'.dta", replace	
erase "$Output\reporting_s_`x'.dta"
erase "$Output\reporting_r_`x'.dta"
}


* IR
use "$Input\_IR.dta", clear
*Obtain the list of first and last reporting year per country and dataset
*We start by identifying for which years each country is reporting as sender
bysort acq year: egen reporter_sender=sum(value), missing
gen report_dummy=1 if reporter_sender!=.
keep acq year report_dummy
*Then, we identify first and last year a country reported
bysort acq: egen first_year_sender_IR=min(year) if report_dummy==1
// bysort acq: egen last_year=max(year) if report_dummy==1
collapse (min) first_year_sender_IR, by(acq)
rename acq ISO
save "$Output\reporting_IR.dta", replace	

* Merge the bases
use "$Output\AT1_aux.dta", clear
merge 1:1 ISO using "$Output\reporting_CPIS.dta"
keep if _merge == 3
drop _merge
merge 1:1 ISO using "$Output\reporting_FDI.dta"
keep if _merge == 3
drop _merge
// // If you have access to Banking database, uncomment this.
// merge 1:1 ISO using "$Output\reporting_IBS.dta"
// keep if _merge == 3
// drop _merge

*Mirror data
// replace first_year_sender_IBS = first_year_receiver_IBS_l if first_year_sender_IBS == . // // If you have access to Banking database, uncomment this.
replace first_year_sender_FDI = first_year_receiver_FDI_l if first_year_sender_FDI == .
merge 1:1 ISO using "$Output\reporting_IR.dta"
keep if _merge == 3
drop _merge

drop *_S *_R caribbean latam cis europe AFR_mena *_l
order n1 s1 africa asia CIS_EUR LAT_CAR mena OFC first_year_sender_CPIS first_year_receiver_CPIS first_year_sender_FDI first_year_receiver_FDI first_year_sender_IR fifth_quintile others OFC n_OFC ,a(country_name)
// order n1 s1 africa asia CIS_EUR LAT_CAR mena OFC first_year_sender_IBS first_year_receiver_IBS first_year_sender_CPIS first_year_receiver_CPIS first_year_sender_FDI first_year_receiver_FDI first_year_sender_IR fifth_quintile others OFC n_OFC ,a(country_name) // If you have access to Banking database, uncomment this.

gsort -n1 -africa -asia -CIS_EUR -LAT_CAR -mena -others -OFC country_name

export excel using "$Output\AT1_OAT1.xlsx", firstrow(variables) replace

erase "$Output\reporting_CPIS.dta"
erase "$Output\reporting_FDI.dta"
erase "$Output\reporting_IR.dta"
// erase "$Output\reporting_IBS.dta"
erase "$Output\AT1_CPIS_S.dta"
erase "$Output\AT1_CPIS_R.dta"
erase "$Output\AT1_FDI_S.dta"
erase "$Output\AT1_FDI_R.dta"
// erase "$Output\AT1_IBS_S.dta"
// erase "$Output\AT1_IBS_R.dta"
erase "$Output\AT1_IR_S.dta"
erase "$Output\aux_GDP_rank_s.dta"
erase "$Output\AT1_aux.dta"
