/* **********************************************************************************************************************************************************************************************
This do file generates the outputs for F3, F4, F5 and OAT5: Granular analysis of regions.

In particular, we calculate the following results:
	- World value by Subregions
	- World value by Regions
	
Note that F4-F5 and OAT5 use the same information. F3 uses the OAT5 table, for update and check the figure, you must copy the table and paste it.
	
The subroups are defined as follow:	
		- Asia (excluding China)
		- China
		- Emerging Europe & Commonwealth of Independent States
		- Middle East and North Africa (If you want both results separately, please uncomment the local names2 and change the local of the first "foreach" loop from names to names2)
		- Latin America (South America, Caribbean Countries and Mexico)
	
Note that we do not deflate prices, given that we will report ratios and not absolute values
// local names asia CIS_EUR AFR_MENA LAT_CAR CHN s1 n1 // Don't separate Africa and Middle East
********************************************************************************************************************************************************************************************** */

clear all
set more off

// local databases "IBS CPIS FDI" // If you have access to banking database, use this local (at Country-to-Country aggregation)
local databases "CPIS FDI"

local names2 CHN asia africa CIS_EUR LAT_CAR mena  // Separate Africa and Middle East

foreach y of local names2 {
foreach x of local databases {
use "$Input\_`x'.dta" ,clear
egen first_year= min(year)
egen last_year=max(year)
* Drop all negative values (generate problems in shares and growth)
drop if value<0

*Separating North and South countries (both exclude offshore centers)
do "$Dofiles\North-South classification_regions.do"

*We exclude Offshore Centers, both as senders and as receivers. We separate China from Emerging Asia, also we calculate Africa and Middle East separately
drop if OFC_acq ==1
drop if OFC_tgt==1
drop OFC_acq OFC_tgt

gen CHN_acq = 0
replace CHN_acq =1 if acq =="CHN"
replace asia_acq = 0 if acq =="CHN"
gen CHN_tgt = 0
replace CHN_tgt =1 if tgt =="CHN" 
replace asia_tgt = 0 if tgt =="CHN"

*2) World and Subgreions values
******************************
* Counting the times that a country appears in sender and receiver position. If this variable is equal to 4, implies that the country is South and "others", so we exclude of aggregates variables(e.g, World_value)
egen nomissing_classification = rownonmiss(n1_acq n1_tgt s1_acq s1_tgt)
*Investments between regions by year
bysort year: egen World_value=sum(value) if nomissing_classification == 4
bysort year: egen N`y'_value=sum(value) if n1_acq==1 & `y'_tgt==1
bysort year: egen `y'N_value=sum(value) if `y'_acq==1 & n1_tgt==1
bysort year: egen S`y'_value=sum(value) if s1_acq==1 & `y'_tgt==1
bysort year: egen `y'S_value=sum(value) if `y'_acq==1 & s1_tgt==1
bysort year: egen `y'`y'_value=sum(value) if `y'_acq==1 & `y'_tgt==1

collapse (min) World_value N`y'_value `y'N_value S`y'_value `y'S_value `y'`y'_value first_year last_year, by(year)

*3) Investments/World GDP
**********************************
*Merging with GDP. We use a special database excluding "other countries" into WorldGDP
* By World GDP
merge 1:1 year using "$Input\regions_gdp_regions.dta"
keep if _merge ==3 
drop _merge

gen N`y'_WorldGDP = N`y'_value / world_R_`x'
gen S`y'_WorldGDP = S`y'_value / world_R_`x'
gen `y'N_WorldGDP = `y'N_value / world_R_`x'
gen `y'S_WorldGDP = `y'S_value / world_R_`x'
gen `y'`y'_WorldGDP = `y'`y'_value / world_R_`x'
keep if year==first_year | year==last_year

// collapse (min) N`y'_WorldGDP `y'N_WorldGDP S`y'_WorldGDP `y'S_WorldGDP `y'`y'_WorldGDP , by(year)
collapse (min) N`y'_WorldGDP `y'N_WorldGDP S`y'_WorldGDP `y'S_WorldGDP `y'`y'_WorldGDP world_R_`x', by(year)
/*
Note: We include the subregion's world GDP because in the subregions growth figure we sum S_subregion + subregion_S, so we substract the cross-flow of subregion to obtain the true growth (overestimated due of double counting)
*/
order year, first
export excel using "$Output\F3_F4_F5_OAT5.xlsx", sheet(`y'_`x') sheetreplace firstrow(variables)
}
}

*** Region - Region
********************************************************************************

foreach x of local databases {
use "$Input\_`x'.dta" ,clear
egen first_year= min(year)
egen last_year=max(year)
* Drop all negative values (generates problems in shares and growth)
drop if value<0

*Separating North and South countries (both exclude offshore centers)
do "$Dofiles\North-South classification_regions.do"

*We exclude Offshore Centers, both as senders and as receivers. We separate China from Emerging Asia, also we calculate Africa and Middle East separately
drop if OFC_acq ==1
drop if OFC_tgt==1
drop OFC_acq OFC_tgt

gen CHN_acq = 0
replace CHN_acq =1 if acq =="CHN"
replace asia_acq = 0 if acq =="CHN"
gen CHN_tgt = 0
replace CHN_tgt =1 if tgt =="CHN" 
replace asia_tgt = 0 if tgt =="CHN"


*2) World and Region Values
******************************
*Investments between regions by year
egen nomissing_classification = rownonmiss(n1_acq n1_tgt s1_acq s1_tgt)
bysort year: egen World_value=sum(value) if nomissing_classification == 4
bysort year: egen NN_value=sum(value) if n1_acq==1 & n1_tgt==1
bysort year: egen NS_value=sum(value) if n1_acq==1 & s1_tgt==1
bysort year: egen SN_value=sum(value) if s1_acq==1 & n1_tgt==1
bysort year: egen SS_value=sum(value) if s1_acq==1 & s1_tgt==1

collapse (min) World_value NN_value NS_value SN_value SS_value first_year last_year, by(year)

*3) Investments/World GDP
**********************************
*Merging with GDP
* By World GDP
merge 1:1 year using "$Input\regions_gdp_regions.dta"
keep if _merge ==3 
drop _merge

gen NN_WorldGDP = NN_value / world_R_`x'
gen NS_WorldGDP = NS_value / world_R_`x'
gen SN_WorldGDP = SN_value / world_R_`x'
gen SS_WorldGDP = SS_value / world_R_`x'
keep if year==first_year | year==last_year

collapse (min) NN_WorldGDP NS_WorldGDP SN_WorldGDP SS_WorldGDP, by(year)
/*
Note: We include the subregion's world GDP because in the subregions growth figure we sum S_subregion + subregion_S, so we substract the cross-flow of subregion to obtain the true growth (overestimated due of double counting)
*/
order year, first
export excel using "$Output\F3_F4_F5_OAT5.xlsx", sheet(World_values_`x') sheetreplace firstrow(variables)
}
