# This script generates the maps of F7: The Proliferation of South - South Links (extensive margin SS connections only)
# In particular, in this script we load the outputs from F7.do and create the figures for the first and last year, per type ...
# of investment.
# NOTE: if you have access to IBS data at Country-to-Country level, and have the output report in F7.do, please, uncomment the IBS
#       part to generate the PNG files.

# Packages
# install.packages("maps")
# install.packages("geosphere")
# install.packages("rworldmap")
# install.packages("rnaturalearth")
# install.packages("rgdal")
# install.packages("tidyverse")
# install.packages("gapminder")
# install.packages("sf")
# install.packages("tmaptools")

# Load library
library(maps) # Maps
library(geosphere)
library(rnaturalearth)
library(rworldmap)
library(rgdal)
library(tidyverse) # pipe
library(ggplot2)
library(gapminder)
library(sf)
library(tmaptools)

# Set directory
setwd("C:/Users/paolo/Dropbox/World Bank/Big Sur/JIE/4.Output/")

# Load the databases
# IBS_2001 <-read.csv("F7_IBS_2001.csv", sep = ",")
CPIS_2001 <-read.csv("F7_CPIS_2001.csv", sep = ",")
FDI_2001 <-read.csv("F7_FDI_2001.csv", sep = ",")
# IBS_2018 <-read.csv("F7_IBS_2018.csv", sep = ",")
CPIS_2018 <-read.csv("F7_CPIS_2018.csv", sep = ",")
FDI_2018 <-read.csv("F7_FDI_2018.csv", sep = ",")

## Preparing data
# Load the ISO code and merge with latitude and longitude
countries <- getMap(resolution = 'low')
countries@data[["ISO_A3"]]

countries$longitude <-coordinates(countries)[,1]
countries$latitude <-coordinates(countries)[,2]
sender_xy <- countries@data %>%
  select(ISO_A3, LON, LAT)

receiver_xy <- countries@data %>%
  select(ISO_A3, LON, LAT)

# NOTE: if you have the database, see the note above.
# ########################
# ###### Map IBS 2001
# ########################
# # Final Bases
# df_final <-IBS_2001 %>% 
#   left_join(sender_xy, by = c ('acq' = 'ISO_A3')) %>% 
#   left_join(receiver_xy, by = c ('tgt' = 'ISO_A3'))
# 
# jpeg("IBS2001.jpeg", width = 500, height =250, quality = 100)
# world1 <- maps::map('world',col="white", fill = TRUE, bg="gray82", lwd=0.1, mar=rep(0,4), interior = FALSE, 
#                     wrap=c(-180,180), border = NA, plot = TRUE)
# 
# # Clear missing values
# df_final <- df_final[complete.cases(df_final),]
# 
# # Make connections
# for (j in 1:length(df_final$acq)){
#   # for (j in 1:13){
#   sender <- c(df_final[j,]$LON.x, df_final[j,]$LAT.x)
#   receiver <- c(df_final[j,]$LON.y, df_final[j,]$LAT.y)
#   
#   inter <- gcIntermediate(c(sender[1],sender[2]),c(receiver[1],receiver[2]), n=100, addStartEnd = TRUE, breakAtDateLine= FALSE)
#   # Correcting lines (when we connect lines between large distances, gcIntermediate generates a
#   # line across all map (eg. If we connect Chile with Hong Kong). The following part eliminates this
#   inter = data.frame(inter)
#   diff_of_lon=abs(sender[1]) + abs(receiver[1])
#   if(diff_of_lon > 180){
#     lines(subset(inter, lon>=0),lwd=0.01, col = "gray60")
#     lines(subset(inter, lon<0), lwd=0.01, col = "gray60")
#   }
#   else{
#     lines(inter, lwd=0.01, col = "gray60")
#   }
# }
# dev.off()
# 
# ########################
# ###### Map IBS 2018
# ########################
# # Final Bases
# df_final <-IBS_2018  %>% 
#   left_join(sender_xy, by = c ('acq' = 'ISO_A3')) %>% 
#   left_join(receiver_xy, by = c ('tgt' = 'ISO_A3'))
# 
# jpeg("IBS2018.jpeg", width = 500, height =250, quality = 100)
# world1 <- maps::map('world',col="white", fill = TRUE, bg="gray82", lwd=0.1, mar=rep(0,4), interior = FALSE, 
#                     wrap=c(-180,180), border = NA, plot = TRUE)
# 
# # Clear missing values
# df_final <- df_final[complete.cases(df_final),]
# 
# # Make connections
# for (j in 1:length(df_final$acq)){
#   # for (j in 1:13){
#   sender <- c(df_final[j,]$LON.x, df_final[j,]$LAT.x)
#   receiver <- c(df_final[j,]$LON.y, df_final[j,]$LAT.y)
#   
#   inter <- gcIntermediate(c(sender[1],sender[2]),c(receiver[1],receiver[2]), n=100, addStartEnd = TRUE, breakAtDateLine= FALSE)
#   # Correcting lines (when we connect lines between large distances, gcIntermediate generates a
#   # line across all map (eg. If we connect Chile with Hong Kong). The following part eliminates this
#   inter = data.frame(inter)
#   diff_of_lon=abs(sender[1]) + abs(receiver[1])
#   if(diff_of_lon > 180){
#     lines(subset(inter, lon>=0),lwd=0.01, col = "gray60")
#     lines(subset(inter, lon<0), lwd=0.01, col = "gray60")
#   }
#   else{
#     lines(inter, lwd=0.01, col = "gray60")
#   }
# }
# dev.off()
########################
###### Map CPIS 2001
########################
# Final Bases
df_final <-CPIS_2001 %>% 
  left_join(sender_xy, by = c ('acq' = 'ISO_A3')) %>% 
  left_join(receiver_xy, by = c ('tgt' = 'ISO_A3'))

jpeg("CPIS2001.jpeg", width = 500, height =250, quality = 100)
world1 <- maps::map('world',col="white", fill = TRUE, bg="gray82", lwd=0.1, mar=rep(0,4), interior = FALSE, 
                    wrap=c(-180,180), border = NA, plot = TRUE)

# Clear missing values
df_final <- df_final[complete.cases(df_final),]

# Make connections
for (j in 1:length(df_final$acq)){
  # for (j in 1:13){
  sender <- c(df_final[j,]$LON.x, df_final[j,]$LAT.x)
  receiver <- c(df_final[j,]$LON.y, df_final[j,]$LAT.y)
  
  inter <- gcIntermediate(c(sender[1],sender[2]),c(receiver[1],receiver[2]), n=100, addStartEnd = TRUE, breakAtDateLine= FALSE)
  # Correcting lines (when we connect lines between large distances, gcIntermediate generates a
  # line across all map (eg. If we connect Chile with Hong Kong). The following part eliminates this
  inter = data.frame(inter)
  diff_of_lon=abs(sender[1]) + abs(receiver[1])
  if(diff_of_lon > 180){
    lines(subset(inter, lon>=0),lwd=0.01, col = "gray60")
    lines(subset(inter, lon<0), lwd=0.01, col = "gray60")
  }
  else{
    lines(inter, lwd=0.01, col = "gray60")
  }
}
dev.off()

########################
###### Map CPIS 2018
########################
# Final Bases
df_final <-CPIS_2018 %>% 
  left_join(sender_xy, by = c ('acq' = 'ISO_A3')) %>% 
  left_join(receiver_xy, by = c ('tgt' = 'ISO_A3'))

jpeg("CPIS2018.jpeg", width = 500, height =250, quality = 100)
world1 <- maps::map('world',col="white", fill = TRUE, bg="gray82", lwd=0.1, mar=rep(0,4), interior = FALSE, 
                    wrap=c(-180,180), border = NA, plot = TRUE)

# Clear missing values
df_final <- df_final[complete.cases(df_final),]

# Make connections
for (j in 1:length(df_final$acq)){
  # for (j in 1:13){
  sender <- c(df_final[j,]$LON.x, df_final[j,]$LAT.x)
  receiver <- c(df_final[j,]$LON.y, df_final[j,]$LAT.y)
  
  inter <- gcIntermediate(c(sender[1],sender[2]),c(receiver[1],receiver[2]), n=100, addStartEnd = TRUE, breakAtDateLine= FALSE)
  # Correcting lines (when we connect lines between large distances, gcIntermediate generates a
  # line across all map (eg. If we connect Chile with Hong Kong). The following part eliminates this
  inter = data.frame(inter)
  diff_of_lon=abs(sender[1]) + abs(receiver[1])
  if(diff_of_lon > 180){
    lines(subset(inter, lon>=0),lwd=0.01, col = "gray60")
    lines(subset(inter, lon<0), lwd=0.01, col = "gray60")
  }
  else{
    lines(inter, lwd=0.01, col = "gray60")
  }
}
dev.off()

########################
###### Map FDI 2001
########################
# Final Bases
df_final <-FDI_2001 %>% 
  left_join(sender_xy, by = c ('acq' = 'ISO_A3')) %>% 
  left_join(receiver_xy, by = c ('tgt' = 'ISO_A3'))

jpeg("FDI2001.jpeg", width = 500, height =250, quality = 100)
world1 <- maps::map('world',col="white", fill = TRUE, bg="gray82", lwd=0.1, mar=rep(0,4), interior = FALSE, 
                    wrap=c(-180,180), border = NA, plot = TRUE)

# Clear missing values
df_final <- df_final[complete.cases(df_final),]

# Make connections
for (j in 1:length(df_final$acq)){
  # for (j in 1:13){
  sender <- c(df_final[j,]$LON.x, df_final[j,]$LAT.x)
  receiver <- c(df_final[j,]$LON.y, df_final[j,]$LAT.y)
  
  inter <- gcIntermediate(c(sender[1],sender[2]),c(receiver[1],receiver[2]), n=100, addStartEnd = TRUE, breakAtDateLine= FALSE)
  # Correcting lines (when we connect lines between large distances, gcIntermediate generates a
  # line across all map (eg. If we connect Chile with Hong Kong). The following part eliminates this
  inter = data.frame(inter)
  diff_of_lon=abs(sender[1]) + abs(receiver[1])
  if(diff_of_lon > 180){
    lines(subset(inter, lon>=0),lwd=0.01, col = "gray60")
    lines(subset(inter, lon<0), lwd=0.01, col = "gray60")
  }
  else{
    lines(inter, lwd=0.01, col = "gray60")
  }
}
dev.off()

########################
###### Map FDI 2018
########################
# Final Bases
df_final <-FDI_2018 %>% 
  left_join(sender_xy, by = c ('acq' = 'ISO_A3')) %>% 
  left_join(receiver_xy, by = c ('tgt' = 'ISO_A3'))

jpeg("FDI2018.jpeg", width = 500, height =250, quality = 100)
world1 <- maps::map('world',col="white", fill = TRUE, bg="gray82", lwd=0.1, mar=rep(0,4), interior = FALSE, 
                    wrap=c(-180,180), border = NA, plot = TRUE)

# Clear missing values
df_final <- df_final[complete.cases(df_final),]

# Make connections
for (j in 1:length(df_final$acq)){
  # for (j in 1:13){
  sender <- c(df_final[j,]$LON.x, df_final[j,]$LAT.x)
  receiver <- c(df_final[j,]$LON.y, df_final[j,]$LAT.y)
  
  inter <- gcIntermediate(c(sender[1],sender[2]),c(receiver[1],receiver[2]), n=100, addStartEnd = TRUE, breakAtDateLine= FALSE)
  # Correcting lines (when we connect lines between large distances, gcIntermediate generates a
  # line across all map (eg. If we connect Chile with Hong Kong). The following part eliminates this
  inter = data.frame(inter)
  diff_of_lon=abs(sender[1]) + abs(receiver[1])
  if(diff_of_lon > 180){
    lines(subset(inter, lon>=0),lwd=0.01, col = "gray60")
    lines(subset(inter, lon<0), lwd=0.01, col = "gray60")
  }
  else{
    lines(inter, lwd=0.01, col = "gray60")
  }
}
dev.off()