/* **********************************************************************************************************************************************************************************************
This do file generates the input for F7 - Maps (Extensive Margin: South-South Connections only)

This do file produces Excel files that are inputs for the software we use to generate the maps
Inside the "Output/Maps" folder there is a description on how to create the maps
	
********************************************************************************************************************************************************************************************** */

clear all
set more off

// local databases "IBS CPIS FDI" // If you have access to banking database, use this local (at Country-to-Country aggregation)
local databases "CPIS FDI"

foreach x of local databases {
use "$Input\_`x'.dta" ,clear 
egen first_year= min(year)
egen last_year=max(year)

*Separating North and South countries (both exclude offshore centers)
do "$Dofiles\North-South classification.do"

*We exclude Offshore Centers, both as senders and as receivers
drop if OFC_acq ==1
drop if OFC_tgt==1
drop OFC_acq OFC_tgt

*We keep only South South connections
keep if s1_acq ==1 & s1_tgt ==1

keep acq tgt year value first_year last_year

*FIRST YEAR
preserve
keep if year == first_year
gen dummy =1 if value!=0 & value!=.
keep if dummy==1
replace value= _n
*Because the software used to create the maps only accepts integer numbers that vary across obs.
*Thus, we cannot export the variable "dummy" because all country-pairs will have the same value link==1.
*With _n each country-pair has a different integer number.
export excel acq tgt value using "$Output\F7.xlsx", sheet(FY_`x') sheetreplace firstrow(variables)
export delimited acq tgt value using "$Output\F7_`x'_2001.csv", delim(",") replace
restore

*LAST YEAR
preserve
keep if year == last_year
gen dummy =1 if value!=0 & value!=.
keep if dummy==1
replace value= _n
export excel acq tgt value using "$Output\F7.xlsx", sheet(LY_`x') sheetreplace firstrow(variables)
export delimited acq tgt value using "$Output\F7_`x'_2018.csv", delim(",") replace
restore

}

