/* **********************************************************************************************************************************************************************************************
This do file generates the input for OAF1  - Number of Source and Destination Countries by Year

This figure shows, for each type of investment, the total number of countries with data as a source and destination each year

A country is considered to have data as a source (destination) in a specific year if  the sum of all cross-border investment positions for which the country is a source (destination) of funds is non-missing. 

For IR, we can calculate the source countries but not the destination because the data is at the C-R level
Thus, we treat this dataset separately

We exclude OFCs

********************************************************************************************************************************************************************************************** */

clear all
set more off

*****************
*Panel A: Source
*****************

***************
* IBS, CPIS and FDI
***************

// local databases "IBS CPIS FDI" // If you have access to banking database, use this local (at Country-to-Country aggregation)
local databases "CPIS FDI"

foreach x of local databases {
use "$Input\_`x'.dta" ,clear 

*Separating North and South countries (both exclude offshore centers)
do "$Dofiles\North-South classification.do"

*We exclude Offshore Centers, both as senders and as receivers
drop if OFC_acq ==1
drop if OFC_tgt==1
drop OFC_acq OFC_tgt

bysort acq year: egen reporter_source=sum(value), missing
duplicates drop acq year, force

gen report_dummy=1 if reporter_source!=.

keep acq year report_dummy

bysort year: egen tot_reporting = sum(report_dummy)
collapse (max) tot_reporting, by(year)

export excel using "$Output\OAF1.xlsx", sheet(`x'_Source) sheetreplace firstrow(variables)

}

local databases "IR"

foreach x of local databases {
use "$Input\_`x'.dta" ,clear 

*IR dataset already identifies region of acq country
*We exclude Offshore Centers as senders (we don't have receiver countries for IR)
drop if OFC_acq ==1
drop OFC_acq

bysort acq year: egen reporter_source=sum(value), missing
duplicates drop acq year, force

gen report_dummy=1 if reporter_source!=.

keep acq year report_dummy

bysort year: egen tot_reporting = sum(report_dummy)
collapse (max) tot_reporting, by(year)

export excel using "$Output\OAF1.xlsx", sheet(`x'_Source) sheetreplace firstrow(variables)

}

*********************
*Panel B: Destination
*********************

local databases "CPIS FDI"  

foreach x of local databases {
use "$Input\_`x'.dta" ,clear 

*Separating North and South countries (both exclude offshore centers)
do "$Dofiles\North-South classification.do"

*We exclude Offshore Centers, both as senders and as receivers
drop if OFC_acq ==1
drop if OFC_tgt==1
drop OFC_acq OFC_tgt

bysort tgt year: egen reporter_dest=sum(value), missing
duplicates drop tgt year, force

gen report_dummy=1 if reporter_dest!=.

keep tgt year report_dummy

bysort year: egen tot_reporting = sum(report_dummy)
collapse (max) tot_reporting, by(year)

export excel using "$Output\OAF1.xlsx", sheet(`x'_Dest) sheetreplace firstrow(variables)

}