/* **********************************************************************************************************************************************************************************************
This do file generates the input for OAF2  - Avg. Share of Counterparts per Year

This figure shows, for each type of investment and region pair, the average ratio of destination countries reported by each source country to all possible destination countries

A country is considered to have data as a source to a specific country in a specific year if the value of cross-border investment positions is non-missing.

We exclude OFCs

********************************************************************************************************************************************************************************************** */

clear all
set more off

/*For each source country, we calculate the number of destinations in the North and the South per year 
and then calculate the average destinations per year across countries for each region-pair
Finally, we calculate the share of average destinations/all possible destinations*/

// local databases "IBS CPIS FDI" // If you have access to banking database, use this local (at Country-to-Country aggregation)
local databases "CPIS FDI"  

foreach x of local databases {
use "$Input\_`x'.dta" ,clear 

*Separating North and South countries (both exclude offshore centers)
do "$Dofiles\North-South classification.do"

*We exclude Offshore Centers, both as senders and as receivers
drop if OFC_acq ==1
drop if OFC_tgt==1
drop OFC_acq OFC_tgt

*Number of counterparts each country has in the North and the South
bysort acq year: egen aux_NN= count(tgt) if value!=. & n1_acq==1 & n1_tgt==1
bysort acq year: egen aux_NS= count(tgt) if value!=. & n1_acq==1 & s1_tgt==1
bysort acq year: egen aux_SN= count(tgt) if value!=. & s1_acq==1 & n1_tgt==1
bysort acq year: egen aux_SS= count(tgt) if value!=. & s1_acq==1 & s1_tgt==1

bysort acq year: egen counter_NN=max(aux_NN)
bysort acq year: egen counter_NS=max(aux_NS)
bysort acq year: egen counter_SN=max(aux_SN)
bysort acq year: egen counter_SS=max(aux_SS)

collapse (min) counter_NN counter_NS counter_SN counter_SS, by(acq year)

*Average across countries per year
collapse (mean) counter_NN counter_NS counter_SN counter_SS, by(year)

*All possible counterparty countries
/*We can't just sum the number of N and S countries because some countries in the database never report as source nor destination for any type of investment. We don't include these in our "sample of countries" (AT1)
Also, there are some reporting countries that appear in banking but not in the rest
So, we directly take the number of countries in each region from the AT1 in the T&F file*/

gen all_N= 40
gen all_S= 174

*Share of destinations reported to all possible destinations
gen NN_share=counter_NN/(all_N-1) //N countries do not report against themselves
gen NS_share=counter_NS/all_S
gen SN_share=counter_SN/all_N
gen SS_share=counter_SS/(all_S-1) //S countries do not report against themselves

keep year NN_share NS_share SN_share SS_share

export excel using "$Output\OAF2.xlsx", sheet(`x') sheetreplace firstrow(variables)

}
