/* **********************************************************************************************************************************************************************************************
This do file generates the input for OAT2 - Intensive Margin - Portfolio Equity vs. Debt

This table shows the statistics of T1 and T2 for portfolio equity and debt separately

In particular, for each region-pair (NN, NS, SN, and SS) we calculate 2 things:
	1) Investments/World GDP
	2) Investments/World Investments
	
Note that we do not deflate prices, given that we will report ratios and not absolute values
********************************************************************************************************************************************************************************************** */

clear all
set more off

local databases "CPIS_equity CPIS_debt"

foreach x of local databases {
use "$Input\_`x'.dta" ,clear 
egen first_year= min(year)
egen last_year=max(year)

*Separating North and South countries (both exclude offshore centers)
do "$Dofiles\North-South classification.do"

*We exclude Offshore Centers, both as senders and as receivers
drop if OFC_acq ==1
drop if OFC_tgt==1
drop OFC_acq OFC_tgt

*Investments between regions by year
bysort year: egen World_value=sum(value)
bysort year: egen NN_value=sum(value) if n1_acq==1 & n1_tgt==1
bysort year: egen NS_value=sum(value) if n1_acq==1 & s1_tgt==1
bysort year: egen SN_value=sum(value) if s1_acq==1 & n1_tgt==1
bysort year: egen SS_value=sum(value) if s1_acq==1 & s1_tgt==1

collapse (min) World_value NN_value NS_value SN_value SS_value first_year last_year, by(year)

*Merging with GDP
merge 1:1 year using "$Input\regions_gdp.dta"
keep if _merge ==3 //The merge is by region, not country. Therefore _merge ==3, except if the year is not included in the main database. We are not dropping obs here.
drop _merge

* 1. Investment/World GDP
*************************
gen NN_WorldGDP = NN_value / world_R_`x'
gen NS_WorldGDP = NS_value / world_R_`x'
gen SN_WorldGDP = SN_value / world_R_`x'
gen SS_WorldGDP = SS_value / world_R_`x'

* 2. Investments/World Investments
**********************************
gen NN_WorldInv = NN_value / World_value
gen NS_WorldInv = NS_value / World_value
gen SN_WorldInv = SN_value / World_value
gen SS_WorldInv = SS_value / World_value

**********************************
*Presenting the Results 
**********************************
keep if year==first_year | year==last_year | year==2007 | year==2008
order year, first
keep year NN_WorldGDP-SS_WorldInv
export excel using "$Output\OAT2.xlsx", sheet(`x') sheetreplace firstrow(variables)
}
