/*********************************************************************************************************************************************************************************************
This do file generates the input for T4 - Robustness OFCs

In particular, we calculate CPIS and FDI investments/World GDP including the OFCs as a new region

In addition, we want to show a column with the value of all investments to world GDP. For this, we want to keep only countries that are considered "reporting" for the three types of investments (CPIS, FDI, and banking). World GDP would be calculated using this sub-sample of countries

We already have data on reporting countries per year per investment type. For CPIS and FDI, we use reporting as sender. In this way, we are consistent with the rest of the table (for more info, see T1_T2 do file). 

- For banking, we need to ask Goetz for the reporting countries

Note that we do not deflate prices, given that we will report ratios and not absolute values
*********************************************************************************************************************************************************************************************/

clear all
set more off

*************
* IBS, CPIS and FDI
*************

// local databases "IBS CPIS FDI" // If you have access to banking database, use this local (at Country-to-Country aggregation)
local databases "CPIS FDI"

foreach x of local databases {
use "$Input\_`x'.dta" ,clear

egen first_year= min(year)
// gen first_year = 2002
egen last_year=max(year)

*Separating North and South countries (both exclude offshore centers)
do "$Dofiles\North-South classification.do"

*In contrast to the other dofiles, we are not excluding OFCs here
*Investments
************
*Investments between regions by year
bysort year: egen World_value=sum(value), missing
bysort year: egen NN_value=sum(value) if n1_acq==1 & n1_tgt==1, missing
bysort year: egen NS_value=sum(value) if n1_acq==1 & s1_tgt==1, missing
bysort year: egen NO_value=sum(value) if n1_acq==1 & OFC_tgt==1, missing
bysort year: egen SN_value=sum(value) if s1_acq==1 & n1_tgt==1, missing
bysort year: egen SS_value=sum(value) if s1_acq==1 & s1_tgt==1, missing
bysort year: egen SO_value=sum(value) if s1_acq==1 & OFC_tgt==1, missing
bysort year: egen ON_value=sum(value) if OFC_acq==1 & n1_tgt==1, missing
bysort year: egen OS_value=sum(value) if OFC_acq==1 & s1_tgt==1, missing
bysort year: egen OO_value=sum(value) if OFC_acq==1 & OFC_tgt==1, missing

collapse (min) World_value NN_value-OO_value first_year last_year, by(year)

*Merging with GDP
merge 1:1 year using "$Input\regions_gdp.dta"
keep if _merge ==3 
drop _merge

*The world GDP doesn't include the OFC so we have to add it
egen world_R_`x'_aux= rowtotal(world_R_`x' OFC_R_`x')
drop world_R_`x'
rename world_R_`x'_aux world_R_`x'

* Investments/World Investments
**********************************
gen NN_WorldGDP = NN_value / world_R_`x'
gen NS_WorldGDP = NS_value / world_R_`x'
gen NO_WorldGDP = NO_value / world_R_`x'
gen SN_WorldGDP = SN_value / world_R_`x'
gen SS_WorldGDP = SS_value / world_R_`x'
gen SO_WorldGDP = SO_value / world_R_`x'
gen ON_WorldGDP = ON_value / world_R_`x'
gen OS_WorldGDP = OS_value / world_R_`x'
gen OO_WorldGDP = OO_value / world_R_`x'

***********************
*Presenting the Results
***********************

keep if year==first_year | year==last_year
collapse (mean) NN_WorldGDP NS_WorldGDP NO_WorldGDP SN_WorldGDP SS_WorldGDP  SO_WorldGDP ON_WorldGDP  OS_WorldGDP OO_WorldGDP, by(year)

order year, first
	
export excel using "$Output\T4_A.xlsx", sheet(`x') sheetreplace firstrow(variables)
}

**************** **************** **************** **************** ************
**************** **************** **************** **************** ************

****** Panel B. North and South including their own OFCs
/*
In this part, we use the advantages of BIS classification (which makes it possible to classify OFCs into main blocks) for replicates the part above.
*/

// local databases "IBS CPIS FDI" // If you have access to banking database, use this local (at Country-to-Country aggregation)
local databases "CPIS FDI"

foreach x of local databases {
use "$Input\_`x'.dta" ,clear

egen first_year= min(year)
egen last_year=max(year)

*Separating North and South countries (both exclude offshore centers)
do "$Dofiles\North-South classification_OFCs.do"

*In contrast to the other dofiles, we are not excluding OFCs here
*Investments
************
*Investments between regions by year
bysort year: egen World_value=sum(value), missing
bysort year: egen NN_value=sum(value) if n1_acq==1 & n1_tgt==1, missing
bysort year: egen NS_value=sum(value) if n1_acq==1 & s1_tgt==1, missing
bysort year: egen SN_value=sum(value) if s1_acq==1 & n1_tgt==1, missing
bysort year: egen SS_value=sum(value) if s1_acq==1 & s1_tgt==1, missing

collapse (min) World_value NN_value-SS_value first_year last_year, by(year)

*Merging with GDP
merge 1:1 year using "$Input\regions_gdp_OFCs.dta"
keep if _merge ==3 
drop _merge

* Investments/World Investments
**********************************
gen NN_WorldGDP = NN_value / world_R_`x'
gen NS_WorldGDP = NS_value / world_R_`x'
gen SN_WorldGDP = SN_value / world_R_`x'
gen SS_WorldGDP = SS_value / world_R_`x'

***********************
*Presenting the Results
***********************

keep if year==first_year | year==last_year
collapse (mean) NN_WorldGDP-SS_WorldGDP, by(year)

order year, first
	
export excel using "$Output\T4_B.xlsx", sheet(`x') sheetreplace firstrow(variables)
}


**************** **************** **************** **************** *************
**************** INTERNATIONAL RESERVES **************** 
**************** **************** **************** **************** *************

use "$Input\_IR.dta" ,clear
egen first_year= min(year)
egen last_year=max(year)

bysort year: egen World_value=sum(value), missing
bysort year: egen NN_value=sum(value) if n1_acq==1 & n1_tgt==1, missing
bysort year: egen NS_value=sum(value) if n1_acq==1 & s1_tgt==1, missing
bysort year: egen SN_value=sum(value) if s1_acq==1 & n1_tgt==1, missing
bysort year: egen SS_value=sum(value) if s1_acq==1 & s1_tgt==1, missing
bysort year: egen ON_value=sum(value) if OFC_acq==1 & n1_tgt==1, missing
bysort year: egen OS_value=sum(value) if OFC_acq==1 & s1_tgt==1, missing

collapse (min) World_value NN_value-OS_value first_year last_year, by(year)
preserve


*Merging with GDP
merge 1:1 year using "$Input\regions_gdp.dta"
keep if _merge ==3 
drop _merge

local x = "IR"
*The world GDP doesn't include the OFC so we have to add it
egen world_S_`x'_aux= rowtotal(world_S_`x' OFC_S_`x')
drop world_S_`x'
rename world_S_`x'_aux world_S_`x'

* Investments/World Investments
**********************************
gen NN_WorldGDP = NN_value / world_S_`x'
gen NS_WorldGDP = NS_value / world_S_`x'
gen SN_WorldGDP = SN_value / world_S_`x'
gen SS_WorldGDP = SS_value / world_S_`x'
gen ON_WorldGDP = ON_value / world_S_`x'
gen OS_WorldGDP = OS_value / world_S_`x'

keep year OS_WorldGDP NN_WorldGDP SN_WorldGDP ON_WorldGDP SS_WorldGDP NS_WorldGDP first_year last_year
keep if year==first_year | year==last_year
collapse (mean)  NN_WorldGDP NS_WorldGDP SN_WorldGDP SS_WorldGDP ON_WorldGDP OS_WorldGDP, by(year)
order year, first

export excel using "$Output\T4_A.xlsx", sheet(IR_with_GDP) sheetreplace firstrow(variables)

**************** **************** **************** **************** ************
**************** **************** **************** **************** ************

****** Panel B. North and South including their own OFCs
/*
In this part, we use the advantages of BIS classification (which makes it possible to classify OFCs into main blocks) for replicates the part above.
*/

use "$Input\_IR.dta" ,clear
egen first_year= min(year)
egen last_year=max(year)

* reassing OFCs to North and South
replace n1_acq=1 if acq=="AND" |acq=="AUT" |acq=="BEL" |acq=="CAN" |acq=="DNK" |acq=="FIN" |acq=="FRA" |acq=="DEU" |acq=="GRC" |acq=="ISL" |acq=="IRL" |acq=="ITA" |acq=="JPN" |acq=="LIE" |acq=="LUX" |acq=="MCO" | ///
acq=="NLD" |acq=="NOR" |acq=="PRT" |acq=="SMR" |acq=="ESP" |acq=="SWE" |acq=="CHE" |acq=="GBR" |acq=="USA" 

* Additional countries in North based on BIS classification (including OFCs) 
	replace n1_acq=1 if inlist(acq,"ABW","AIA","AND","ANT","AUS","BES","BMU","CUW","CYM")
	replace n1_acq=1 if inlist(acq,"CYP","EST","FLK","FRO","GGY","GIB","GRL","IMN","JEY")
	replace n1_acq=1 if inlist(acq,"LIE","LTU","LVA","MLT","MSR","NCL","NZL","PUS","PYF")
	replace n1_acq=1 if inlist(acq,"SHN","SVK","SVN","SXM","TCA","VAT","VGB","WIN","WLF")

replace s1_acq=1 if n1_acq==0 
*Investments
************
*Investments between regions by year
bysort year: egen NN_value=sum(value) if n1_acq==1 & n1_tgt==1, missing
bysort year: egen NS_value=sum(value) if n1_acq==1 & s1_tgt==1, missing
bysort year: egen SN_value=sum(value) if s1_acq==1 & n1_tgt==1, missing
bysort year: egen SS_value=sum(value) if s1_acq==1 & s1_tgt==1, missing

collapse (min) NN_value-SS_value first_year last_year, by(year)


*Merging with GDP
merge 1:1 year using "$Input\regions_gdp_OFCs.dta"
keep if _merge ==3 
drop _merge

* Investments/World Investments
**********************************
gen NN_WorldGDP = NN_value / world_S_IR
gen NS_WorldGDP = NS_value / world_S_IR
gen SN_WorldGDP = SN_value / world_S_IR
gen SS_WorldGDP = SS_value / world_S_IR

***********************
*Presenting the Results
***********************

keep if year==first_year | year==last_year
collapse (mean) NN_WorldGDP-SS_WorldGDP, by(year)

order year, first
	
export excel using "$Output\T4_B.xlsx", sheet(IR_with_GDP) sheetreplace firstrow(variables)
