/* **********************************************************************************************************************************************************************************************
This do file generates the input for T7 (Extensive Margin).

In particular, for each region-pair we calculate 2 things:
	1) T6: Percentage of Active Connections Relative to All Possible Connections within Blocks
	2) T7: Percentage of Active Connections Relative to All Existing Active World Connections

All possible connections include positive, negative and zero connections. Missing are not counted.
********************************************************************************************************************************************************************************************** */
clear all
set more off

// local databases "IBS CPIS FDI" // If you have access to banking database, use this local (at Country-to-Country aggregation)
local databases "CPIS FDI"

foreach x of local databases {
use "$Input\_`x'.dta" ,clear 
egen first_year= min(year)
egen last_year=max(year)

*Separating North and South countries (both exclude offshore centers)
do "$Dofiles\North-South classification.do"

*We exclude Offshore Centers, both as senders and as receivers
drop if OFC_acq ==1
drop if OFC_tgt==1
drop OFC_acq OFC_tgt

***************************
* % of Active Connections
***************************
*Note: The % of active connections is computed as the number of country-pairs that have a positive or negative value in each year over the number of country-pairs with a positive, negative or zero value in that same year (we do not include missing)


*Active Links per year
bysort year: egen count_NN=count(value) if value!=0 & value!=. & n1_acq==1 & n1_tgt==1
bysort year: egen count_NS=count(value) if value!=0 & value!=. & n1_acq==1 & s1_tgt==1
bysort year: egen count_SN=count(value) if value!=0 & value!=. & s1_acq==1 & n1_tgt==1
bysort year: egen count_SS=count(value) if value!=0 & value!=. & s1_acq==1 & s1_tgt==1

*All possible links between region-pairs
bysort year: egen count_TOTAL_NN=count(value) if value!=. & n1_acq==1 & n1_tgt==1
bysort year: egen count_TOTAL_NS=count(value) if value!=. & n1_acq==1 & s1_tgt==1
bysort year: egen count_TOTAL_SN=count(value) if value!=. & s1_acq==1 & n1_tgt==1
bysort year: egen count_TOTAL_SS=count(value) if value!=. & s1_acq==1 & s1_tgt==1

*All active connections worldwide per year
bysort year: egen count_TOTAL_active=count(value) if value!=0 & value!=.

*Percentage of Active Connections
**********************************
*Active links/All possible connections between region-pair
gen NN_region=count_NN / count_TOTAL_NN
gen NS_region=count_NS / count_TOTAL_NS
gen SN_region=count_SN / count_TOTAL_SN
gen SS_region=count_SS / count_TOTAL_SS

*Active links/All active connections worldwide
gen NN_world=count_NN / count_TOTAL_active
gen NS_world=count_NS / count_TOTAL_active
gen SN_world=count_SN / count_TOTAL_active
gen SS_world=count_SS / count_TOTAL_active


collapse (min) NN_region-SS_world first_year last_year, by(year)

************************
*Presenting the Results
************************	
	keep if year==first_year | year==last_year | year==2007 | year==2008 | year==2009
	collapse (mean) NN_region-SS_world first_year last_year, by(year)
	
	order year, first
	export excel using "$Output\T7.xlsx", sheet(`x') sheetreplace firstrow(variables)
}

