/**********************************************************************************************************************************************************************************************
This do file generates the input for Figure 2 - Evolution of Regional Level Investments and Connections

For each investment type and year, it calculates the value of old and new connections, and percentage of active connections

- The % of active connections is computed as the number of country-pairs that have a positive or negative value in each year over the number of country-pairs with a positive, negative or zero value in that same year. Note that many values are missing (they are not zeros) and we are not counting these observations in the denominator.
   
- New investments are defined as those investments attributable to connections that were not present in the 1st year of each database (2001)

- Old investments are defined as those investments attributable to connections that were already present in the 1st year of each database (2001)
   
We define the "1st period" as the first year in our sample (2001)
   
Flows are expressed in trillions of 2011 USD.	
**********************************************************************************************************************************************************************************************/
clear all
set more off
global Input_price "${dir}\2.Cleaned Databases"

local databases "LBS"
foreach x of local databases {
use "$Input\_`x' R-R.dta" ,clear

*We need to define a "1st period" to distinguish old and new connections
*In our case, we define the period to be the first year in each dataset (2001)

*Deflating prices (2011 billions USD)
merge m:1 year using "$Input_price\PRICE_DEFLATOR.dta"
drop if _merge != 3
foreach z in NN NS SN SS{
	replace `z'_value = (`z'_value/ deflator)
}
drop _merge deflator

* Merge with World GDP
merge 1:1 year using "$Input\regions_gdp.dta", keepus(world_R_`x')


foreach y in NN NS SN SS{
bys year: gen `y'_total = (`y'_value)/world_R_`x'
}

drop _merge world_R_`x'
order year NN_total-SS_total
// 	gr tw (line NN_value NS_value SN_value SS_value year), yscale(log) // OK!

export excel using "$Output\F2.xlsx", sheet(`x') sheetreplace firstrow(variables)
}
