/* **********************************************************************************************************************************************************************************************
This do file generates the input for T1 and T2 (Intensive Margin)

In particular, for each region-pair (NN, NS, SN, and SS) we calculate 2 things:
	1) Investments/World GDP
	2) Investments/World Investments

We calculate this for first year, 2007, 2008, 2009, and last year
	
Note that we do not deflate prices, given that we will report ratios and not absolute values

The data for international reserves has a different structure so we treat it separately:
- It is as the C-R level (we don't have receiver countries)
- We already identified N and S countries
********************************************************************************************************************************************************************************************** */

clear all
set more off

***************
* LBS
***************

local databases "LBS"

foreach x of local databases {
use "$Input\_`x' R-R.dta" ,clear 

*Merging with GDP
merge 1:1 year using "$Input\regions_gdp.dta"
keep if _merge ==3 //The merge is by region, not country. Therefore _merge ==3, except if the year is not included in the main database. We are not dropping obs here.
drop _merge

* 1. Investment/World GDP
*************************
// We use world receivers GDP (instead of world senders GDP). All senders are also receivers in our sample. So, by using the GDP of all receivers we are considering the GDP of all countries that participate in a region's cross-border flows
gen NN_WorldGDP = NN_value / world_R_`x'
gen NS_WorldGDP = NS_value / world_R_`x'
gen SN_WorldGDP = SN_value / world_R_`x'
gen SS_WorldGDP = SS_value / world_R_`x'

* 2. Investments/World Investments
**********************************
gen NN_WorldInv = NN_value / World_value
gen NS_WorldInv = NS_value / World_value
gen SN_WorldInv = SN_value / World_value
gen SS_WorldInv = SS_value / World_value

**********************************
*Presenting the Results 
**********************************
keep if year==first_year | year==last_year | year==2007 | year==2008 | year==2009
order year, first
keep year NN_WorldGDP-SS_WorldInv NN_value-SS_value
order year NN_WorldGDP-SS_WorldInv NN_value-SS_value
export excel using "$Output\T1_T2.xlsx", sheet(`x') sheetreplace firstrow(variables)

}
