/*********************************************************************************************************************************************************************************************
This do file generates the input for T4 - Robustness OFCs

In particular, we calculate CPIS and FDI investments/World GDP including the OFCs as a new region

In addition, we want to show a column with the value of all investments to world GDP. For this, we want to keep only countries that are considered "reporting" for the three types of investments (CPIS, FDI, and banking). World GDP would be calculated using this sub-sample of countries

We already have data on reporting countries per year per investment type. For CPIS and FDI, we use reporting as sender. In this way, we are consistent with the rest of the table (for more info, see T1_T2 do file). 

- For banking, we need to ask Goetz for the reporting countries

Note that we do not deflate prices, given that we will report ratios and not absolute values
*********************************************************************************************************************************************************************************************/

clear all
set more off

*************
* LBS
*************

local databases "LBS"

foreach x of local databases {
use "$Input\_`x' R-R-R.dta" ,clear

egen first_year= min(year)
// gen first_year = 2002
egen last_year=max(year)


*In contrast to the other dofiles, we are not excluding OFCs here
*Investments
************
*Investments between regions by year
// bysort year: egen World_value=sum(value), missing
// bysort year: egen NN_value=sum(value) if n1_acq==1 & n1_tgt==1, missing
// bysort year: egen NS_value=sum(value) if n1_acq==1 & s1_tgt==1, missing
// bysort year: egen NO_value=sum(value) if n1_acq==1 & OFC_tgt==1, missing
// bysort year: egen SN_value=sum(value) if s1_acq==1 & n1_tgt==1, missing
// bysort year: egen SS_value=sum(value) if s1_acq==1 & s1_tgt==1, missing
// bysort year: egen SO_value=sum(value) if s1_acq==1 & OFC_tgt==1, missing
// bysort year: egen ON_value=sum(value) if OFC_acq==1 & n1_tgt==1, missing
// bysort year: egen OS_value=sum(value) if OFC_acq==1 & s1_tgt==1, missing
// bysort year: egen OO_value=sum(value) if OFC_acq==1 & OFC_tgt==1, missing
//
// collapse (min) World_value NN_value-OO_value first_year last_year, by(year)
//
*Merging with GDP
// merge 1:1 year using "$Input\regions_gdp.dta"
// keep if _merge ==3 
// drop _merge
//
*The world GDP doesn't include the OFC so we have to add it
// egen world_R_`x'_aux= rowtotal(world_R_`x' OFC_R_`x')
// drop world_R_`x'
// rename world_R_`x'_aux world_R_`x'
//
// * Investments/World Investments
// **********************************
// gen NN_WorldGDP = NN_value / world_R_`x'
// gen NS_WorldGDP = NS_value / world_R_`x'
// gen NO_WorldGDP = NO_value / world_R_`x'
// gen SN_WorldGDP = SN_value / world_R_`x'
// gen SS_WorldGDP = SS_value / world_R_`x'
// gen SO_WorldGDP = SO_value / world_R_`x'
// gen ON_WorldGDP = ON_value / world_R_`x'
// gen OS_WorldGDP = OS_value / world_R_`x'
// gen OO_WorldGDP = OO_value / world_R_`x'

***********************
*Presenting the Results
***********************

keep if year==first_year | year==last_year
collapse (mean) NN_WorldGDP NS_WorldGDP NO_WorldGDP SN_WorldGDP SS_WorldGDP  SO_WorldGDP ON_WorldGDP  OS_WorldGDP OO_WorldGDP, by(year)

order year, first
	
export excel using "$Output\T4_A.xlsx", sheet(`x') sheetreplace firstrow(variables)
}
